
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl/enum.h>


namespace gl43ext
{


// use enum type
using gl::GLenum;


// import enums to namespace
using gl::GL_1PASS_EXT;
using gl::GL_1PASS_SGIS;
using gl::GL_2_BYTES_NV;
using gl::GL_2PASS_0_EXT;
using gl::GL_2PASS_0_SGIS;
using gl::GL_2PASS_1_EXT;
using gl::GL_2PASS_1_SGIS;
using gl::GL_3_BYTES_NV;
using gl::GL_422_AVERAGE_EXT;
using gl::GL_422_EXT;
using gl::GL_422_REV_AVERAGE_EXT;
using gl::GL_422_REV_EXT;
using gl::GL_4_BYTES_NV;
using gl::GL_4PASS_0_EXT;
using gl::GL_4PASS_0_SGIS;
using gl::GL_4PASS_1_EXT;
using gl::GL_4PASS_1_SGIS;
using gl::GL_4PASS_2_EXT;
using gl::GL_4PASS_2_SGIS;
using gl::GL_4PASS_3_EXT;
using gl::GL_4PASS_3_SGIS;
using gl::GL_ABGR_EXT;
using gl::GL_ACCUM_ADJACENT_PAIRS_NV;
using gl::GL_ACTIVE_PROGRAM_EXT;
using gl::GL_ACTIVE_STENCIL_FACE_EXT;
using gl::GL_ACTIVE_TEXTURE_ARB;
using gl::GL_ACTIVE_VARYING_MAX_LENGTH_NV;
using gl::GL_ACTIVE_VARYINGS_NV;
using gl::GL_ACTIVE_VERTEX_UNITS_ARB;
using gl::GL_ADD_ATI;
using gl::GL_ADD_SIGNED_ARB;
using gl::GL_ADD_SIGNED_EXT;
using gl::GL_ADJACENT_PAIRS_NV;
using gl::GL_AFFINE_2D_NV;
using gl::GL_AFFINE_3D_NV;
using gl::GL_ALL_COMPLETED_NV;
using gl::GL_ALL_STATIC_DATA_IBM;
using gl::GL_ALLOW_DRAW_FRG_HINT_PGI;
using gl::GL_ALLOW_DRAW_MEM_HINT_PGI;
using gl::GL_ALLOW_DRAW_OBJ_HINT_PGI;
using gl::GL_ALLOW_DRAW_WIN_HINT_PGI;
using gl::GL_ALPHA12_EXT;
using gl::GL_ALPHA16_EXT;
using gl::GL_ALPHA16_SNORM;
using gl::GL_ALPHA16F_ARB;
using gl::GL_ALPHA16F_EXT;
using gl::GL_ALPHA16I_EXT;
using gl::GL_ALPHA16UI_EXT;
using gl::GL_ALPHA32F_ARB;
using gl::GL_ALPHA32F_EXT;
using gl::GL_ALPHA32I_EXT;
using gl::GL_ALPHA32UI_EXT;
using gl::GL_ALPHA4_EXT;
using gl::GL_ALPHA8_EXT;
using gl::GL_ALPHA8_SNORM;
using gl::GL_ALPHA8I_EXT;
using gl::GL_ALPHA8UI_EXT;
using gl::GL_ALPHA_FLOAT16_APPLE;
using gl::GL_ALPHA_FLOAT16_ATI;
using gl::GL_ALPHA_FLOAT32_APPLE;
using gl::GL_ALPHA_FLOAT32_ATI;
using gl::GL_ALPHA_INTEGER_EXT;
using gl::GL_ALPHA_MAX_CLAMP_INGR;
using gl::GL_ALPHA_MAX_SGIX;
using gl::GL_ALPHA_MIN_CLAMP_INGR;
using gl::GL_ALPHA_MIN_SGIX;
using gl::GL_ALPHA_REF_COMMAND_NV;
using gl::GL_ALPHA_SNORM;
using gl::GL_ALPHA_TO_COVERAGE_DITHER_DEFAULT_NV;
using gl::GL_ALPHA_TO_COVERAGE_DITHER_DISABLE_NV;
using gl::GL_ALPHA_TO_COVERAGE_DITHER_ENABLE_NV;
using gl::GL_ALPHA_TO_COVERAGE_DITHER_MODE_NV;
using gl::GL_ALWAYS_FAST_HINT_PGI;
using gl::GL_ALWAYS_SOFT_HINT_PGI;
using gl::GL_ARC_TO_NV;
using gl::GL_ARRAY_BUFFER_ARB;
using gl::GL_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_ARRAY_ELEMENT_LOCK_COUNT_EXT;
using gl::GL_ARRAY_ELEMENT_LOCK_FIRST_EXT;
using gl::GL_ARRAY_OBJECT_BUFFER_ATI;
using gl::GL_ARRAY_OBJECT_OFFSET_ATI;
using gl::GL_ASYNC_DRAW_PIXELS_SGIX;
using gl::GL_ASYNC_HISTOGRAM_SGIX;
using gl::GL_ASYNC_MARKER_SGIX;
using gl::GL_ASYNC_READ_PIXELS_SGIX;
using gl::GL_ASYNC_TEX_IMAGE_SGIX;
using gl::GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_MESH_SHADER_NV;
using gl::GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TASK_SHADER_NV;
using gl::GL_ATTACHED_MEMORY_OBJECT_NV;
using gl::GL_ATTACHED_MEMORY_OFFSET_NV;
using gl::GL_ATTENUATION_EXT;
using gl::GL_ATTRIB_ARRAY_POINTER_NV;
using gl::GL_ATTRIB_ARRAY_SIZE_NV;
using gl::GL_ATTRIB_ARRAY_STRIDE_NV;
using gl::GL_ATTRIB_ARRAY_TYPE_NV;
using gl::GL_ATTRIBUTE_ADDRESS_COMMAND_NV;
using gl::GL_AUX_DEPTH_STENCIL_APPLE;
using gl::GL_AVERAGE_EXT;
using gl::GL_AVERAGE_HP;
using gl::GL_BACK_NORMALS_HINT_PGI;
using gl::GL_BACK_PRIMARY_COLOR_NV;
using gl::GL_BACK_SECONDARY_COLOR_NV;
using gl::GL_BEVEL_NV;
using gl::GL_BGR_EXT;
using gl::GL_BGR_INTEGER_EXT;
using gl::GL_BGRA8_EXT;
using gl::GL_BGRA_EXT;
using gl::GL_BGRA_INTEGER_EXT;
using gl::GL_BIAS_BY_NEGATIVE_ONE_HALF_NV;
using gl::GL_BINORMAL_ARRAY_EXT;
using gl::GL_BINORMAL_ARRAY_POINTER_EXT;
using gl::GL_BINORMAL_ARRAY_STRIDE_EXT;
using gl::GL_BINORMAL_ARRAY_TYPE_EXT;
using gl::GL_BLACKHOLE_RENDER_INTEL;
using gl::GL_BLEND_ADVANCED_COHERENT_KHR;
using gl::GL_BLEND_ADVANCED_COHERENT_NV;
using gl::GL_BLEND_COLOR_COMMAND_NV;
using gl::GL_BLEND_COLOR_EXT;
using gl::GL_BLEND_DST_ALPHA_EXT;
using gl::GL_BLEND_DST_RGB_EXT;
using gl::GL_BLEND_EQUATION_ALPHA_EXT;
using gl::GL_BLEND_EQUATION_EXT;
using gl::GL_BLEND_EQUATION_RGB_EXT;
using gl::GL_BLEND_OVERLAP_NV;
using gl::GL_BLEND_PREMULTIPLIED_SRC_NV;
using gl::GL_BLEND_SRC_ALPHA_EXT;
using gl::GL_BLEND_SRC_RGB_EXT;
using gl::GL_BLUE_INTEGER_EXT;
using gl::GL_BLUE_MAX_CLAMP_INGR;
using gl::GL_BLUE_MIN_CLAMP_INGR;
using gl::GL_BLUE_NV;
using gl::GL_BOOL_ARB;
using gl::GL_BOOL_VEC2_ARB;
using gl::GL_BOOL_VEC3_ARB;
using gl::GL_BOOL_VEC4_ARB;
using gl::GL_BOUNDING_BOX_NV;
using gl::GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV;
using gl::GL_BUFFER_ACCESS_ARB;
using gl::GL_BUFFER_FLUSHING_UNMAP_APPLE;
using gl::GL_BUFFER_GPU_ADDRESS_NV;
using gl::GL_BUFFER_IMMUTABLE_STORAGE;
using gl::GL_BUFFER_KHR;
using gl::GL_BUFFER_MAP_POINTER_ARB;
using gl::GL_BUFFER_MAPPED_ARB;
using gl::GL_BUFFER_OBJECT_APPLE;
using gl::GL_BUFFER_OBJECT_EXT;
using gl::GL_BUFFER_SERIALIZED_MODIFY_APPLE;
using gl::GL_BUFFER_SIZE_ARB;
using gl::GL_BUFFER_STORAGE_FLAGS;
using gl::GL_BUFFER_USAGE_ARB;
using gl::GL_BUMP_ENVMAP_ATI;
using gl::GL_BUMP_NUM_TEX_UNITS_ATI;
using gl::GL_BUMP_ROT_MATRIX_ATI;
using gl::GL_BUMP_ROT_MATRIX_SIZE_ATI;
using gl::GL_BUMP_TARGET_ATI;
using gl::GL_BUMP_TEX_UNITS_ATI;
using gl::GL_CALLIGRAPHIC_FRAGMENT_SGIX;
using gl::GL_CIRCULAR_CCW_ARC_TO_NV;
using gl::GL_CIRCULAR_CW_ARC_TO_NV;
using gl::GL_CIRCULAR_TANGENT_ARC_TO_NV;
using gl::GL_CLAMP_FRAGMENT_COLOR_ARB;
using gl::GL_CLAMP_READ_COLOR_ARB;
using gl::GL_CLAMP_TO_BORDER_ARB;
using gl::GL_CLAMP_TO_BORDER_SGIS;
using gl::GL_CLAMP_TO_EDGE_SGIS;
using gl::GL_CLAMP_VERTEX_COLOR_ARB;
using gl::GL_CLEAR_TEXTURE;
using gl::GL_CLIENT_ACTIVE_TEXTURE_ARB;
using gl::GL_CLIP_DEPTH_MODE;
using gl::GL_CLIP_DISTANCE_NV;
using gl::GL_CLIP_FAR_HINT_PGI;
using gl::GL_CLIP_NEAR_HINT_PGI;
using gl::GL_CLIP_ORIGIN;
using gl::GL_CLIP_VOLUME_CLIPPING_HINT_EXT;
using gl::GL_CLIPPING_INPUT_PRIMITIVES;
using gl::GL_CLIPPING_INPUT_PRIMITIVES_ARB;
using gl::GL_CLIPPING_OUTPUT_PRIMITIVES;
using gl::GL_CLIPPING_OUTPUT_PRIMITIVES_ARB;
using gl::GL_CLOSE_PATH_NV;
using gl::GL_CMYK_EXT;
using gl::GL_CMYKA_EXT;
using gl::GL_CND0_ATI;
using gl::GL_CND_ATI;
using gl::GL_COLOR_ALPHA_PAIRING_ATI;
using gl::GL_COLOR_ARRAY_ADDRESS_NV;
using gl::GL_COLOR_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_COLOR_ARRAY_COUNT_EXT;
using gl::GL_COLOR_ARRAY_EXT;
using gl::GL_COLOR_ARRAY_LENGTH_NV;
using gl::GL_COLOR_ARRAY_LIST_IBM;
using gl::GL_COLOR_ARRAY_LIST_STRIDE_IBM;
using gl::GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL;
using gl::GL_COLOR_ARRAY_POINTER_EXT;
using gl::GL_COLOR_ARRAY_SIZE_EXT;
using gl::GL_COLOR_ARRAY_STRIDE_EXT;
using gl::GL_COLOR_ARRAY_TYPE_EXT;
using gl::GL_COLOR_ATTACHMENT0_EXT;
using gl::GL_COLOR_ATTACHMENT10_EXT;
using gl::GL_COLOR_ATTACHMENT11_EXT;
using gl::GL_COLOR_ATTACHMENT12_EXT;
using gl::GL_COLOR_ATTACHMENT13_EXT;
using gl::GL_COLOR_ATTACHMENT14_EXT;
using gl::GL_COLOR_ATTACHMENT15_EXT;
using gl::GL_COLOR_ATTACHMENT1_EXT;
using gl::GL_COLOR_ATTACHMENT2_EXT;
using gl::GL_COLOR_ATTACHMENT3_EXT;
using gl::GL_COLOR_ATTACHMENT4_EXT;
using gl::GL_COLOR_ATTACHMENT5_EXT;
using gl::GL_COLOR_ATTACHMENT6_EXT;
using gl::GL_COLOR_ATTACHMENT7_EXT;
using gl::GL_COLOR_ATTACHMENT8_EXT;
using gl::GL_COLOR_ATTACHMENT9_EXT;
using gl::GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI;
using gl::GL_COLOR_FLOAT_APPLE;
using gl::GL_COLOR_INDEX12_EXT;
using gl::GL_COLOR_INDEX16_EXT;
using gl::GL_COLOR_INDEX1_EXT;
using gl::GL_COLOR_INDEX2_EXT;
using gl::GL_COLOR_INDEX4_EXT;
using gl::GL_COLOR_INDEX8_EXT;
using gl::GL_COLOR_MATRIX;
using gl::GL_COLOR_MATRIX_SGI;
using gl::GL_COLOR_MATRIX_STACK_DEPTH;
using gl::GL_COLOR_MATRIX_STACK_DEPTH_SGI;
using gl::GL_COLOR_SAMPLES_NV;
using gl::GL_COLOR_SUM_ARB;
using gl::GL_COLOR_SUM_CLAMP_NV;
using gl::GL_COLOR_SUM_EXT;
using gl::GL_COLOR_TABLE;
using gl::GL_COLOR_TABLE_ALPHA_SIZE;
using gl::GL_COLOR_TABLE_ALPHA_SIZE_SGI;
using gl::GL_COLOR_TABLE_BIAS;
using gl::GL_COLOR_TABLE_BIAS_SGI;
using gl::GL_COLOR_TABLE_BLUE_SIZE;
using gl::GL_COLOR_TABLE_BLUE_SIZE_SGI;
using gl::GL_COLOR_TABLE_FORMAT;
using gl::GL_COLOR_TABLE_FORMAT_SGI;
using gl::GL_COLOR_TABLE_GREEN_SIZE;
using gl::GL_COLOR_TABLE_GREEN_SIZE_SGI;
using gl::GL_COLOR_TABLE_INTENSITY_SIZE;
using gl::GL_COLOR_TABLE_INTENSITY_SIZE_SGI;
using gl::GL_COLOR_TABLE_LUMINANCE_SIZE;
using gl::GL_COLOR_TABLE_LUMINANCE_SIZE_SGI;
using gl::GL_COLOR_TABLE_RED_SIZE;
using gl::GL_COLOR_TABLE_RED_SIZE_SGI;
using gl::GL_COLOR_TABLE_SCALE;
using gl::GL_COLOR_TABLE_SCALE_SGI;
using gl::GL_COLOR_TABLE_SGI;
using gl::GL_COLOR_TABLE_WIDTH;
using gl::GL_COLOR_TABLE_WIDTH_SGI;
using gl::GL_COLORBURN_KHR;
using gl::GL_COLORBURN_NV;
using gl::GL_COLORDODGE_KHR;
using gl::GL_COLORDODGE_NV;
using gl::GL_COMBINE4_NV;
using gl::GL_COMBINE_ALPHA_ARB;
using gl::GL_COMBINE_ALPHA_EXT;
using gl::GL_COMBINE_ARB;
using gl::GL_COMBINE_EXT;
using gl::GL_COMBINE_RGB_ARB;
using gl::GL_COMBINE_RGB_EXT;
using gl::GL_COMBINER0_NV;
using gl::GL_COMBINER1_NV;
using gl::GL_COMBINER2_NV;
using gl::GL_COMBINER3_NV;
using gl::GL_COMBINER4_NV;
using gl::GL_COMBINER5_NV;
using gl::GL_COMBINER6_NV;
using gl::GL_COMBINER7_NV;
using gl::GL_COMBINER_AB_DOT_PRODUCT_NV;
using gl::GL_COMBINER_AB_OUTPUT_NV;
using gl::GL_COMBINER_BIAS_NV;
using gl::GL_COMBINER_CD_DOT_PRODUCT_NV;
using gl::GL_COMBINER_CD_OUTPUT_NV;
using gl::GL_COMBINER_COMPONENT_USAGE_NV;
using gl::GL_COMBINER_INPUT_NV;
using gl::GL_COMBINER_MAPPING_NV;
using gl::GL_COMBINER_MUX_SUM_NV;
using gl::GL_COMBINER_SCALE_NV;
using gl::GL_COMBINER_SUM_OUTPUT_NV;
using gl::GL_COMPARE_R_TO_TEXTURE_ARB;
using gl::GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT;
using gl::GL_COMPLETION_STATUS_ARB;
using gl::GL_COMPLETION_STATUS_KHR;
using gl::GL_COMPRESSED_ALPHA_ARB;
using gl::GL_COMPRESSED_INTENSITY_ARB;
using gl::GL_COMPRESSED_LUMINANCE_ALPHA_ARB;
using gl::GL_COMPRESSED_LUMINANCE_ALPHA_LATC2_EXT;
using gl::GL_COMPRESSED_LUMINANCE_ARB;
using gl::GL_COMPRESSED_LUMINANCE_LATC1_EXT;
using gl::GL_COMPRESSED_RED_GREEN_RGTC2_EXT;
using gl::GL_COMPRESSED_RED_RGTC1_EXT;
using gl::GL_COMPRESSED_RGB_ARB;
using gl::GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT_ARB;
using gl::GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_ARB;
using gl::GL_COMPRESSED_RGB_FXT1_3DFX;
using gl::GL_COMPRESSED_RGB_S3TC_DXT1_EXT;
using gl::GL_COMPRESSED_RGBA_ARB;
using gl::GL_COMPRESSED_RGBA_ASTC_10x10_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_10x5_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_10x6_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_10x8_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_12x10_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_12x12_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_4x4_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_5x4_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_5x5_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_6x5_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_6x6_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_8x5_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_8x6_KHR;
using gl::GL_COMPRESSED_RGBA_ASTC_8x8_KHR;
using gl::GL_COMPRESSED_RGBA_BPTC_UNORM_ARB;
using gl::GL_COMPRESSED_RGBA_FXT1_3DFX;
using gl::GL_COMPRESSED_RGBA_S3TC_DXT1_EXT;
using gl::GL_COMPRESSED_RGBA_S3TC_DXT3_EXT;
using gl::GL_COMPRESSED_RGBA_S3TC_DXT5_EXT;
using gl::GL_COMPRESSED_SIGNED_LUMINANCE_ALPHA_LATC2_EXT;
using gl::GL_COMPRESSED_SIGNED_LUMINANCE_LATC1_EXT;
using gl::GL_COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT;
using gl::GL_COMPRESSED_SIGNED_RED_RGTC1_EXT;
using gl::GL_COMPRESSED_SLUMINANCE_ALPHA_EXT;
using gl::GL_COMPRESSED_SLUMINANCE_EXT;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR;
using gl::GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR;
using gl::GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM_ARB;
using gl::GL_COMPRESSED_SRGB_ALPHA_EXT;
using gl::GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT;
using gl::GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT;
using gl::GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT;
using gl::GL_COMPRESSED_SRGB_EXT;
using gl::GL_COMPRESSED_SRGB_S3TC_DXT1_EXT;
using gl::GL_COMPRESSED_TEXTURE_FORMATS_ARB;
using gl::GL_COMPUTE_PROGRAM_NV;
using gl::GL_COMPUTE_PROGRAM_PARAMETER_BUFFER_NV;
using gl::GL_COMPUTE_SHADER_INVOCATIONS;
using gl::GL_COMPUTE_SHADER_INVOCATIONS_ARB;
using gl::GL_CON_0_ATI;
using gl::GL_CON_10_ATI;
using gl::GL_CON_11_ATI;
using gl::GL_CON_12_ATI;
using gl::GL_CON_13_ATI;
using gl::GL_CON_14_ATI;
using gl::GL_CON_15_ATI;
using gl::GL_CON_16_ATI;
using gl::GL_CON_17_ATI;
using gl::GL_CON_18_ATI;
using gl::GL_CON_19_ATI;
using gl::GL_CON_1_ATI;
using gl::GL_CON_20_ATI;
using gl::GL_CON_21_ATI;
using gl::GL_CON_22_ATI;
using gl::GL_CON_23_ATI;
using gl::GL_CON_24_ATI;
using gl::GL_CON_25_ATI;
using gl::GL_CON_26_ATI;
using gl::GL_CON_27_ATI;
using gl::GL_CON_28_ATI;
using gl::GL_CON_29_ATI;
using gl::GL_CON_2_ATI;
using gl::GL_CON_30_ATI;
using gl::GL_CON_31_ATI;
using gl::GL_CON_3_ATI;
using gl::GL_CON_4_ATI;
using gl::GL_CON_5_ATI;
using gl::GL_CON_6_ATI;
using gl::GL_CON_7_ATI;
using gl::GL_CON_8_ATI;
using gl::GL_CON_9_ATI;
using gl::GL_CONFORMANT_NV;
using gl::GL_CONIC_CURVE_TO_NV;
using gl::GL_CONJOINT_NV;
using gl::GL_CONSERVATIVE_RASTER_DILATE_GRANULARITY_NV;
using gl::GL_CONSERVATIVE_RASTER_DILATE_NV;
using gl::GL_CONSERVATIVE_RASTER_DILATE_RANGE_NV;
using gl::GL_CONSERVATIVE_RASTER_MODE_NV;
using gl::GL_CONSERVATIVE_RASTER_MODE_POST_SNAP_NV;
using gl::GL_CONSERVATIVE_RASTER_MODE_PRE_SNAP_NV;
using gl::GL_CONSERVATIVE_RASTER_MODE_PRE_SNAP_TRIANGLES_NV;
using gl::GL_CONSERVATIVE_RASTERIZATION_INTEL;
using gl::GL_CONSERVATIVE_RASTERIZATION_NV;
using gl::GL_CONSERVE_MEMORY_HINT_PGI;
using gl::GL_CONST_BW_TILING_MESA;
using gl::GL_CONST_EYE_NV;
using gl::GL_CONSTANT_ALPHA_EXT;
using gl::GL_CONSTANT_ARB;
using gl::GL_CONSTANT_BORDER;
using gl::GL_CONSTANT_BORDER_HP;
using gl::GL_CONSTANT_COLOR0_NV;
using gl::GL_CONSTANT_COLOR1_NV;
using gl::GL_CONSTANT_COLOR_EXT;
using gl::GL_CONSTANT_EXT;
using gl::GL_CONSTANT_NV;
using gl::GL_CONTEXT_LOST;
using gl::GL_CONTEXT_LOST_KHR;
using gl::GL_CONTEXT_RELEASE_BEHAVIOR;
using gl::GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH;
using gl::GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH_KHR;
using gl::GL_CONTEXT_RELEASE_BEHAVIOR_KHR;
using gl::GL_CONTEXT_ROBUST_ACCESS;
using gl::GL_CONTEXT_ROBUST_ACCESS_KHR;
using gl::GL_CONTINUOUS_AMD;
using gl::GL_CONTRAST_NV;
using gl::GL_CONVEX_HULL_NV;
using gl::GL_CONVOLUTION_1D;
using gl::GL_CONVOLUTION_1D_EXT;
using gl::GL_CONVOLUTION_2D;
using gl::GL_CONVOLUTION_2D_EXT;
using gl::GL_CONVOLUTION_BORDER_COLOR;
using gl::GL_CONVOLUTION_BORDER_COLOR_HP;
using gl::GL_CONVOLUTION_BORDER_MODE;
using gl::GL_CONVOLUTION_BORDER_MODE_EXT;
using gl::GL_CONVOLUTION_FILTER_BIAS;
using gl::GL_CONVOLUTION_FILTER_BIAS_EXT;
using gl::GL_CONVOLUTION_FILTER_SCALE;
using gl::GL_CONVOLUTION_FILTER_SCALE_EXT;
using gl::GL_CONVOLUTION_FORMAT;
using gl::GL_CONVOLUTION_FORMAT_EXT;
using gl::GL_CONVOLUTION_HEIGHT;
using gl::GL_CONVOLUTION_HEIGHT_EXT;
using gl::GL_CONVOLUTION_HINT_SGIX;
using gl::GL_CONVOLUTION_WIDTH;
using gl::GL_CONVOLUTION_WIDTH_EXT;
using gl::GL_COORD_REPLACE_ARB;
using gl::GL_COORD_REPLACE_NV;
using gl::GL_COUNT_DOWN_NV;
using gl::GL_COUNT_UP_NV;
using gl::GL_COUNTER_RANGE_AMD;
using gl::GL_COUNTER_TYPE_AMD;
using gl::GL_COVERAGE_MODULATION_NV;
using gl::GL_COVERAGE_MODULATION_TABLE_NV;
using gl::GL_COVERAGE_MODULATION_TABLE_SIZE_NV;
using gl::GL_CUBIC_CURVE_TO_NV;
using gl::GL_CUBIC_EXT;
using gl::GL_CUBIC_HP;
using gl::GL_CULL_FRAGMENT_NV;
using gl::GL_CULL_MODES_NV;
using gl::GL_CULL_VERTEX_EXT;
using gl::GL_CULL_VERTEX_EYE_POSITION_EXT;
using gl::GL_CULL_VERTEX_IBM;
using gl::GL_CULL_VERTEX_OBJECT_POSITION_EXT;
using gl::GL_CURRENT_ATTRIB_NV;
using gl::GL_CURRENT_BINORMAL_EXT;
using gl::GL_CURRENT_FOG_COORDINATE_EXT;
using gl::GL_CURRENT_MATRIX_ARB;
using gl::GL_CURRENT_MATRIX_INDEX_ARB;
using gl::GL_CURRENT_MATRIX_NV;
using gl::GL_CURRENT_MATRIX_STACK_DEPTH_ARB;
using gl::GL_CURRENT_MATRIX_STACK_DEPTH_NV;
using gl::GL_CURRENT_OCCLUSION_QUERY_ID_NV;
using gl::GL_CURRENT_PALETTE_MATRIX_ARB;
using gl::GL_CURRENT_QUERY_ARB;
using gl::GL_CURRENT_RASTER_NORMAL_SGIX;
using gl::GL_CURRENT_SECONDARY_COLOR_EXT;
using gl::GL_CURRENT_TANGENT_EXT;
using gl::GL_CURRENT_TIME_NV;
using gl::GL_CURRENT_VERTEX_ATTRIB_ARB;
using gl::GL_CURRENT_VERTEX_EXT;
using gl::GL_CURRENT_VERTEX_WEIGHT_EXT;
using gl::GL_CURRENT_WEIGHT_ARB;
using gl::GL_D3D12_FENCE_VALUE_EXT;
using gl::GL_DARKEN_KHR;
using gl::GL_DARKEN_NV;
using gl::GL_DATA_BUFFER_AMD;
using gl::GL_DEBUG_CALLBACK_FUNCTION_ARB;
using gl::GL_DEBUG_CALLBACK_FUNCTION_KHR;
using gl::GL_DEBUG_CALLBACK_USER_PARAM_ARB;
using gl::GL_DEBUG_CALLBACK_USER_PARAM_KHR;
using gl::GL_DEBUG_CATEGORY_API_ERROR_AMD;
using gl::GL_DEBUG_CATEGORY_APPLICATION_AMD;
using gl::GL_DEBUG_CATEGORY_DEPRECATION_AMD;
using gl::GL_DEBUG_CATEGORY_OTHER_AMD;
using gl::GL_DEBUG_CATEGORY_PERFORMANCE_AMD;
using gl::GL_DEBUG_CATEGORY_SHADER_COMPILER_AMD;
using gl::GL_DEBUG_CATEGORY_UNDEFINED_BEHAVIOR_AMD;
using gl::GL_DEBUG_CATEGORY_WINDOW_SYSTEM_AMD;
using gl::GL_DEBUG_GROUP_STACK_DEPTH_KHR;
using gl::GL_DEBUG_LOGGED_MESSAGES_AMD;
using gl::GL_DEBUG_LOGGED_MESSAGES_ARB;
using gl::GL_DEBUG_LOGGED_MESSAGES_KHR;
using gl::GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_ARB;
using gl::GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_KHR;
using gl::GL_DEBUG_OUTPUT_KHR;
using gl::GL_DEBUG_OUTPUT_SYNCHRONOUS_ARB;
using gl::GL_DEBUG_OUTPUT_SYNCHRONOUS_KHR;
using gl::GL_DEBUG_SEVERITY_HIGH_AMD;
using gl::GL_DEBUG_SEVERITY_HIGH_ARB;
using gl::GL_DEBUG_SEVERITY_HIGH_KHR;
using gl::GL_DEBUG_SEVERITY_LOW_AMD;
using gl::GL_DEBUG_SEVERITY_LOW_ARB;
using gl::GL_DEBUG_SEVERITY_LOW_KHR;
using gl::GL_DEBUG_SEVERITY_MEDIUM_AMD;
using gl::GL_DEBUG_SEVERITY_MEDIUM_ARB;
using gl::GL_DEBUG_SEVERITY_MEDIUM_KHR;
using gl::GL_DEBUG_SEVERITY_NOTIFICATION_KHR;
using gl::GL_DEBUG_SOURCE_API_ARB;
using gl::GL_DEBUG_SOURCE_API_KHR;
using gl::GL_DEBUG_SOURCE_APPLICATION_ARB;
using gl::GL_DEBUG_SOURCE_APPLICATION_KHR;
using gl::GL_DEBUG_SOURCE_OTHER_ARB;
using gl::GL_DEBUG_SOURCE_OTHER_KHR;
using gl::GL_DEBUG_SOURCE_SHADER_COMPILER_ARB;
using gl::GL_DEBUG_SOURCE_SHADER_COMPILER_KHR;
using gl::GL_DEBUG_SOURCE_THIRD_PARTY_ARB;
using gl::GL_DEBUG_SOURCE_THIRD_PARTY_KHR;
using gl::GL_DEBUG_SOURCE_WINDOW_SYSTEM_ARB;
using gl::GL_DEBUG_SOURCE_WINDOW_SYSTEM_KHR;
using gl::GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_ARB;
using gl::GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_KHR;
using gl::GL_DEBUG_TYPE_ERROR_ARB;
using gl::GL_DEBUG_TYPE_ERROR_KHR;
using gl::GL_DEBUG_TYPE_MARKER_KHR;
using gl::GL_DEBUG_TYPE_OTHER_ARB;
using gl::GL_DEBUG_TYPE_OTHER_KHR;
using gl::GL_DEBUG_TYPE_PERFORMANCE_ARB;
using gl::GL_DEBUG_TYPE_PERFORMANCE_KHR;
using gl::GL_DEBUG_TYPE_POP_GROUP_KHR;
using gl::GL_DEBUG_TYPE_PORTABILITY_ARB;
using gl::GL_DEBUG_TYPE_PORTABILITY_KHR;
using gl::GL_DEBUG_TYPE_PUSH_GROUP_KHR;
using gl::GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_ARB;
using gl::GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_KHR;
using gl::GL_DECODE_EXT;
using gl::GL_DECR_WRAP_EXT;
using gl::GL_DEDICATED_MEMORY_OBJECT_EXT;
using gl::GL_DEFORMATIONS_MASK_SGIX;
using gl::GL_DEPENDENT_AR_TEXTURE_2D_NV;
using gl::GL_DEPENDENT_GB_TEXTURE_2D_NV;
using gl::GL_DEPENDENT_HILO_TEXTURE_2D_NV;
using gl::GL_DEPENDENT_RGB_TEXTURE_3D_NV;
using gl::GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV;
using gl::GL_DEPTH24_STENCIL8_EXT;
using gl::GL_DEPTH32F_STENCIL8_NV;
using gl::GL_DEPTH_ATTACHMENT_EXT;
using gl::GL_DEPTH_BOUNDS_EXT;
using gl::GL_DEPTH_BOUNDS_TEST_EXT;
using gl::GL_DEPTH_BUFFER_FLOAT_MODE_NV;
using gl::GL_DEPTH_CLAMP_FAR_AMD;
using gl::GL_DEPTH_CLAMP_NEAR_AMD;
using gl::GL_DEPTH_CLAMP_NV;
using gl::GL_DEPTH_COMPONENT16_ARB;
using gl::GL_DEPTH_COMPONENT16_SGIX;
using gl::GL_DEPTH_COMPONENT24_ARB;
using gl::GL_DEPTH_COMPONENT24_SGIX;
using gl::GL_DEPTH_COMPONENT32_ARB;
using gl::GL_DEPTH_COMPONENT32_SGIX;
using gl::GL_DEPTH_COMPONENT32F_NV;
using gl::GL_DEPTH_SAMPLES_NV;
using gl::GL_DEPTH_STENCIL_EXT;
using gl::GL_DEPTH_STENCIL_NV;
using gl::GL_DEPTH_STENCIL_TO_BGRA_NV;
using gl::GL_DEPTH_STENCIL_TO_RGBA_NV;
using gl::GL_DEPTH_TEXTURE_MODE_ARB;
using gl::GL_DETACHED_BUFFERS_NV;
using gl::GL_DETACHED_MEMORY_INCARNATION_NV;
using gl::GL_DETACHED_TEXTURES_NV;
using gl::GL_DETAIL_TEXTURE_2D_BINDING_SGIS;
using gl::GL_DETAIL_TEXTURE_2D_SGIS;
using gl::GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS;
using gl::GL_DETAIL_TEXTURE_LEVEL_SGIS;
using gl::GL_DETAIL_TEXTURE_MODE_SGIS;
using gl::GL_DEVICE_LUID_EXT;
using gl::GL_DEVICE_NODE_MASK_EXT;
using gl::GL_DEVICE_UUID_EXT;
using gl::GL_DIFFERENCE_KHR;
using gl::GL_DIFFERENCE_NV;
using gl::GL_DISCARD_ATI;
using gl::GL_DISCARD_NV;
using gl::GL_DISCRETE_AMD;
using gl::GL_DISJOINT_NV;
using gl::GL_DISTANCE_ATTENUATION_EXT;
using gl::GL_DISTANCE_ATTENUATION_SGIS;
using gl::GL_DOT2_ADD_ATI;
using gl::GL_DOT3_ATI;
using gl::GL_DOT3_RGB_ARB;
using gl::GL_DOT3_RGB_EXT;
using gl::GL_DOT3_RGBA_ARB;
using gl::GL_DOT3_RGBA_EXT;
using gl::GL_DOT4_ATI;
using gl::GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV;
using gl::GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV;
using gl::GL_DOT_PRODUCT_DEPTH_REPLACE_NV;
using gl::GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV;
using gl::GL_DOT_PRODUCT_NV;
using gl::GL_DOT_PRODUCT_PASS_THROUGH_NV;
using gl::GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV;
using gl::GL_DOT_PRODUCT_TEXTURE_1D_NV;
using gl::GL_DOT_PRODUCT_TEXTURE_2D_NV;
using gl::GL_DOT_PRODUCT_TEXTURE_3D_NV;
using gl::GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV;
using gl::GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV;
using gl::GL_DOUBLE_MAT2_EXT;
using gl::GL_DOUBLE_MAT2x3_EXT;
using gl::GL_DOUBLE_MAT2x4_EXT;
using gl::GL_DOUBLE_MAT3_EXT;
using gl::GL_DOUBLE_MAT3x2_EXT;
using gl::GL_DOUBLE_MAT3x4_EXT;
using gl::GL_DOUBLE_MAT4_EXT;
using gl::GL_DOUBLE_MAT4x2_EXT;
using gl::GL_DOUBLE_MAT4x3_EXT;
using gl::GL_DOUBLE_VEC2_EXT;
using gl::GL_DOUBLE_VEC3_EXT;
using gl::GL_DOUBLE_VEC4_EXT;
using gl::GL_DRAW_ARRAYS_COMMAND_NV;
using gl::GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV;
using gl::GL_DRAW_ARRAYS_STRIP_COMMAND_NV;
using gl::GL_DRAW_BUFFER0_ARB;
using gl::GL_DRAW_BUFFER0_ATI;
using gl::GL_DRAW_BUFFER10_ARB;
using gl::GL_DRAW_BUFFER10_ATI;
using gl::GL_DRAW_BUFFER11_ARB;
using gl::GL_DRAW_BUFFER11_ATI;
using gl::GL_DRAW_BUFFER12_ARB;
using gl::GL_DRAW_BUFFER12_ATI;
using gl::GL_DRAW_BUFFER13_ARB;
using gl::GL_DRAW_BUFFER13_ATI;
using gl::GL_DRAW_BUFFER14_ARB;
using gl::GL_DRAW_BUFFER14_ATI;
using gl::GL_DRAW_BUFFER15_ARB;
using gl::GL_DRAW_BUFFER15_ATI;
using gl::GL_DRAW_BUFFER1_ARB;
using gl::GL_DRAW_BUFFER1_ATI;
using gl::GL_DRAW_BUFFER2_ARB;
using gl::GL_DRAW_BUFFER2_ATI;
using gl::GL_DRAW_BUFFER3_ARB;
using gl::GL_DRAW_BUFFER3_ATI;
using gl::GL_DRAW_BUFFER4_ARB;
using gl::GL_DRAW_BUFFER4_ATI;
using gl::GL_DRAW_BUFFER5_ARB;
using gl::GL_DRAW_BUFFER5_ATI;
using gl::GL_DRAW_BUFFER6_ARB;
using gl::GL_DRAW_BUFFER6_ATI;
using gl::GL_DRAW_BUFFER7_ARB;
using gl::GL_DRAW_BUFFER7_ATI;
using gl::GL_DRAW_BUFFER8_ARB;
using gl::GL_DRAW_BUFFER8_ATI;
using gl::GL_DRAW_BUFFER9_ARB;
using gl::GL_DRAW_BUFFER9_ATI;
using gl::GL_DRAW_ELEMENTS_COMMAND_NV;
using gl::GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV;
using gl::GL_DRAW_ELEMENTS_STRIP_COMMAND_NV;
using gl::GL_DRAW_FRAMEBUFFER_BINDING_EXT;
using gl::GL_DRAW_FRAMEBUFFER_EXT;
using gl::GL_DRAW_INDIRECT_ADDRESS_NV;
using gl::GL_DRAW_INDIRECT_LENGTH_NV;
using gl::GL_DRAW_INDIRECT_UNIFIED_NV;
using gl::GL_DRAW_PIXELS_APPLE;
using gl::GL_DRIVER_UUID_EXT;
using gl::GL_DS_BIAS_NV;
using gl::GL_DS_SCALE_NV;
using gl::GL_DSDT8_MAG8_INTENSITY8_NV;
using gl::GL_DSDT8_MAG8_NV;
using gl::GL_DSDT8_NV;
using gl::GL_DSDT_MAG_INTENSITY_NV;
using gl::GL_DSDT_MAG_NV;
using gl::GL_DSDT_MAG_VIB_NV;
using gl::GL_DSDT_NV;
using gl::GL_DST_ATOP_NV;
using gl::GL_DST_IN_NV;
using gl::GL_DST_NV;
using gl::GL_DST_OUT_NV;
using gl::GL_DST_OVER_NV;
using gl::GL_DT_BIAS_NV;
using gl::GL_DT_SCALE_NV;
using gl::GL_DU8DV8_ATI;
using gl::GL_DUAL_ALPHA12_SGIS;
using gl::GL_DUAL_ALPHA16_SGIS;
using gl::GL_DUAL_ALPHA4_SGIS;
using gl::GL_DUAL_ALPHA8_SGIS;
using gl::GL_DUAL_INTENSITY12_SGIS;
using gl::GL_DUAL_INTENSITY16_SGIS;
using gl::GL_DUAL_INTENSITY4_SGIS;
using gl::GL_DUAL_INTENSITY8_SGIS;
using gl::GL_DUAL_LUMINANCE12_SGIS;
using gl::GL_DUAL_LUMINANCE16_SGIS;
using gl::GL_DUAL_LUMINANCE4_SGIS;
using gl::GL_DUAL_LUMINANCE8_SGIS;
using gl::GL_DUAL_LUMINANCE_ALPHA4_SGIS;
using gl::GL_DUAL_LUMINANCE_ALPHA8_SGIS;
using gl::GL_DUAL_TEXTURE_SELECT_SGIS;
using gl::GL_DUDV_ATI;
using gl::GL_DUP_FIRST_CUBIC_CURVE_TO_NV;
using gl::GL_DUP_LAST_CUBIC_CURVE_TO_NV;
using gl::GL_DYNAMIC_ATI;
using gl::GL_DYNAMIC_COPY_ARB;
using gl::GL_DYNAMIC_DRAW_ARB;
using gl::GL_DYNAMIC_READ_ARB;
using gl::GL_E_TIMES_F_NV;
using gl::GL_EDGE_FLAG_ARRAY_ADDRESS_NV;
using gl::GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_EDGE_FLAG_ARRAY_COUNT_EXT;
using gl::GL_EDGE_FLAG_ARRAY_EXT;
using gl::GL_EDGE_FLAG_ARRAY_LENGTH_NV;
using gl::GL_EDGE_FLAG_ARRAY_LIST_IBM;
using gl::GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM;
using gl::GL_EDGE_FLAG_ARRAY_POINTER_EXT;
using gl::GL_EDGE_FLAG_ARRAY_STRIDE_EXT;
using gl::GL_EFFECTIVE_RASTER_SAMPLES_EXT;
using gl::GL_ELEMENT_ADDRESS_COMMAND_NV;
using gl::GL_ELEMENT_ARRAY_ADDRESS_NV;
using gl::GL_ELEMENT_ARRAY_APPLE;
using gl::GL_ELEMENT_ARRAY_ATI;
using gl::GL_ELEMENT_ARRAY_BUFFER_ARB;
using gl::GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_ELEMENT_ARRAY_LENGTH_NV;
using gl::GL_ELEMENT_ARRAY_POINTER_APPLE;
using gl::GL_ELEMENT_ARRAY_POINTER_ATI;
using gl::GL_ELEMENT_ARRAY_TYPE_APPLE;
using gl::GL_ELEMENT_ARRAY_TYPE_ATI;
using gl::GL_ELEMENT_ARRAY_UNIFIED_NV;
using gl::GL_EMBOSS_CONSTANT_NV;
using gl::GL_EMBOSS_LIGHT_NV;
using gl::GL_EMBOSS_MAP_NV;
using gl::GL_EVAL_2D_NV;
using gl::GL_EVAL_FRACTIONAL_TESSELLATION_NV;
using gl::GL_EVAL_TRIANGULAR_2D_NV;
using gl::GL_EVAL_VERTEX_ATTRIB0_NV;
using gl::GL_EVAL_VERTEX_ATTRIB10_NV;
using gl::GL_EVAL_VERTEX_ATTRIB11_NV;
using gl::GL_EVAL_VERTEX_ATTRIB12_NV;
using gl::GL_EVAL_VERTEX_ATTRIB13_NV;
using gl::GL_EVAL_VERTEX_ATTRIB14_NV;
using gl::GL_EVAL_VERTEX_ATTRIB15_NV;
using gl::GL_EVAL_VERTEX_ATTRIB1_NV;
using gl::GL_EVAL_VERTEX_ATTRIB2_NV;
using gl::GL_EVAL_VERTEX_ATTRIB3_NV;
using gl::GL_EVAL_VERTEX_ATTRIB4_NV;
using gl::GL_EVAL_VERTEX_ATTRIB5_NV;
using gl::GL_EVAL_VERTEX_ATTRIB6_NV;
using gl::GL_EVAL_VERTEX_ATTRIB7_NV;
using gl::GL_EVAL_VERTEX_ATTRIB8_NV;
using gl::GL_EVAL_VERTEX_ATTRIB9_NV;
using gl::GL_EXCLUSION_KHR;
using gl::GL_EXCLUSION_NV;
using gl::GL_EXCLUSIVE_EXT;
using gl::GL_EXPAND_NEGATE_NV;
using gl::GL_EXPAND_NORMAL_NV;
using gl::GL_EXTERNAL_VIRTUAL_MEMORY_BUFFER_AMD;
using gl::GL_EYE_DISTANCE_TO_LINE_SGIS;
using gl::GL_EYE_DISTANCE_TO_POINT_SGIS;
using gl::GL_EYE_LINE_SGIS;
using gl::GL_EYE_LINEAR_NV;
using gl::GL_EYE_PLANE_ABSOLUTE_NV;
using gl::GL_EYE_POINT_SGIS;
using gl::GL_EYE_RADIAL_NV;
using gl::GL_FACTOR_MAX_AMD;
using gl::GL_FACTOR_MIN_AMD;
using gl::GL_FAILURE_NV;
using gl::GL_FENCE_APPLE;
using gl::GL_FENCE_CONDITION_NV;
using gl::GL_FENCE_STATUS_NV;
using gl::GL_FIELD_LOWER_NV;
using gl::GL_FIELD_UPPER_NV;
using gl::GL_FIELDS_NV;
using gl::GL_FILE_NAME_NV;
using gl::GL_FILL_RECTANGLE_NV;
using gl::GL_FILTER4_SGIS;
using gl::GL_FIRST_TO_REST_NV;
using gl::GL_FIRST_VERTEX_CONVENTION_EXT;
using gl::GL_FIXED_OES;
using gl::GL_FIXED_ONLY_ARB;
using gl::GL_FLOAT16_MAT2_AMD;
using gl::GL_FLOAT16_MAT2x3_AMD;
using gl::GL_FLOAT16_MAT2x4_AMD;
using gl::GL_FLOAT16_MAT3_AMD;
using gl::GL_FLOAT16_MAT3x2_AMD;
using gl::GL_FLOAT16_MAT3x4_AMD;
using gl::GL_FLOAT16_MAT4_AMD;
using gl::GL_FLOAT16_MAT4x2_AMD;
using gl::GL_FLOAT16_MAT4x3_AMD;
using gl::GL_FLOAT16_NV;
using gl::GL_FLOAT16_VEC2_NV;
using gl::GL_FLOAT16_VEC3_NV;
using gl::GL_FLOAT16_VEC4_NV;
using gl::GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV;
using gl::GL_FLOAT_CLEAR_COLOR_VALUE_NV;
using gl::GL_FLOAT_MAT2_ARB;
using gl::GL_FLOAT_MAT3_ARB;
using gl::GL_FLOAT_MAT4_ARB;
using gl::GL_FLOAT_R16_NV;
using gl::GL_FLOAT_R32_NV;
using gl::GL_FLOAT_R_NV;
using gl::GL_FLOAT_RG16_NV;
using gl::GL_FLOAT_RG32_NV;
using gl::GL_FLOAT_RG_NV;
using gl::GL_FLOAT_RGB16_NV;
using gl::GL_FLOAT_RGB32_NV;
using gl::GL_FLOAT_RGB_NV;
using gl::GL_FLOAT_RGBA16_NV;
using gl::GL_FLOAT_RGBA32_NV;
using gl::GL_FLOAT_RGBA_MODE_NV;
using gl::GL_FLOAT_RGBA_NV;
using gl::GL_FLOAT_VEC2_ARB;
using gl::GL_FLOAT_VEC3_ARB;
using gl::GL_FLOAT_VEC4_ARB;
using gl::GL_FOG_COORD_ARRAY_ADDRESS_NV;
using gl::GL_FOG_COORD_ARRAY_LENGTH_NV;
using gl::GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_FOG_COORDINATE_ARRAY_EXT;
using gl::GL_FOG_COORDINATE_ARRAY_LIST_IBM;
using gl::GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM;
using gl::GL_FOG_COORDINATE_ARRAY_POINTER_EXT;
using gl::GL_FOG_COORDINATE_ARRAY_STRIDE_EXT;
using gl::GL_FOG_COORDINATE_ARRAY_TYPE_EXT;
using gl::GL_FOG_COORDINATE_EXT;
using gl::GL_FOG_COORDINATE_SOURCE_EXT;
using gl::GL_FOG_DISTANCE_MODE_NV;
using gl::GL_FOG_FUNC_POINTS_SGIS;
using gl::GL_FOG_FUNC_SGIS;
using gl::GL_FOG_OFFSET_SGIX;
using gl::GL_FOG_OFFSET_VALUE_SGIX;
using gl::GL_FOG_SPECULAR_TEXTURE_WIN;
using gl::GL_FONT_GLYPHS_AVAILABLE_NV;
using gl::GL_FONT_TARGET_UNAVAILABLE_NV;
using gl::GL_FONT_UNAVAILABLE_NV;
using gl::GL_FONT_UNINTELLIGIBLE_NV;
using gl::GL_FORCE_BLUE_TO_ONE_NV;
using gl::GL_FORMAT_SUBSAMPLE_244_244_OML;
using gl::GL_FORMAT_SUBSAMPLE_24_24_OML;
using gl::GL_FRAGMENT_COLOR_EXT;
using gl::GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX;
using gl::GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX;
using gl::GL_FRAGMENT_COLOR_MATERIAL_SGIX;
using gl::GL_FRAGMENT_COVERAGE_COLOR_NV;
using gl::GL_FRAGMENT_COVERAGE_TO_COLOR_NV;
using gl::GL_FRAGMENT_DEPTH_EXT;
using gl::GL_FRAGMENT_INPUT_NV;
using gl::GL_FRAGMENT_LIGHT0_SGIX;
using gl::GL_FRAGMENT_LIGHT1_SGIX;
using gl::GL_FRAGMENT_LIGHT2_SGIX;
using gl::GL_FRAGMENT_LIGHT3_SGIX;
using gl::GL_FRAGMENT_LIGHT4_SGIX;
using gl::GL_FRAGMENT_LIGHT5_SGIX;
using gl::GL_FRAGMENT_LIGHT6_SGIX;
using gl::GL_FRAGMENT_LIGHT7_SGIX;
using gl::GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX;
using gl::GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX;
using gl::GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX;
using gl::GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX;
using gl::GL_FRAGMENT_LIGHTING_SGIX;
using gl::GL_FRAGMENT_MATERIAL_EXT;
using gl::GL_FRAGMENT_NORMAL_EXT;
using gl::GL_FRAGMENT_PROGRAM_ARB;
using gl::GL_FRAGMENT_PROGRAM_BINDING_NV;
using gl::GL_FRAGMENT_PROGRAM_INTERPOLATION_OFFSET_BITS_NV;
using gl::GL_FRAGMENT_PROGRAM_NV;
using gl::GL_FRAGMENT_PROGRAM_PARAMETER_BUFFER_NV;
using gl::GL_FRAGMENT_SHADER_ARB;
using gl::GL_FRAGMENT_SHADER_ATI;
using gl::GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB;
using gl::GL_FRAGMENT_SHADER_DISCARDS_SAMPLES_EXT;
using gl::GL_FRAGMENT_SHADER_INVOCATIONS;
using gl::GL_FRAGMENT_SHADER_INVOCATIONS_ARB;
using gl::GL_FRAME_NV;
using gl::GL_FRAMEBUFFER_ATTACHMENT_LAYERED_ARB;
using gl::GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_BASE_VIEW_INDEX_OVR;
using gl::GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT;
using gl::GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_NUM_VIEWS_OVR;
using gl::GL_FRAMEBUFFER_BINDING_EXT;
using gl::GL_FRAMEBUFFER_COMPLETE_EXT;
using gl::GL_FRAMEBUFFER_EXT;
using gl::GL_FRAMEBUFFER_FLIP_X_MESA;
using gl::GL_FRAMEBUFFER_FLIP_Y_MESA;
using gl::GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_ARB;
using gl::GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_ARB;
using gl::GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT;
using gl::GL_FRAMEBUFFER_INCOMPLETE_VIEW_TARGETS_OVR;
using gl::GL_FRAMEBUFFER_PROGRAMMABLE_SAMPLE_LOCATIONS_ARB;
using gl::GL_FRAMEBUFFER_PROGRAMMABLE_SAMPLE_LOCATIONS_NV;
using gl::GL_FRAMEBUFFER_SAMPLE_LOCATION_PIXEL_GRID_ARB;
using gl::GL_FRAMEBUFFER_SAMPLE_LOCATION_PIXEL_GRID_NV;
using gl::GL_FRAMEBUFFER_SRGB_CAPABLE_EXT;
using gl::GL_FRAMEBUFFER_SRGB_EXT;
using gl::GL_FRAMEBUFFER_SWAP_XY_MESA;
using gl::GL_FRAMEBUFFER_UNSUPPORTED_EXT;
using gl::GL_FRAMEZOOM_FACTOR_SGIX;
using gl::GL_FRAMEZOOM_SGIX;
using gl::GL_FRONT_FACE_COMMAND_NV;
using gl::GL_FULL_RANGE_EXT;
using gl::GL_FULL_STIPPLE_HINT_PGI;
using gl::GL_FUNC_ADD_EXT;
using gl::GL_FUNC_REVERSE_SUBTRACT_EXT;
using gl::GL_FUNC_SUBTRACT_EXT;
using gl::GL_GENERATE_MIPMAP_HINT_SGIS;
using gl::GL_GENERATE_MIPMAP_SGIS;
using gl::GL_GENERIC_ATTRIB_NV;
using gl::GL_GEOMETRY_DEFORMATION_SGIX;
using gl::GL_GEOMETRY_INPUT_TYPE_ARB;
using gl::GL_GEOMETRY_INPUT_TYPE_EXT;
using gl::GL_GEOMETRY_OUTPUT_TYPE_ARB;
using gl::GL_GEOMETRY_OUTPUT_TYPE_EXT;
using gl::GL_GEOMETRY_PROGRAM_NV;
using gl::GL_GEOMETRY_PROGRAM_PARAMETER_BUFFER_NV;
using gl::GL_GEOMETRY_SHADER_ARB;
using gl::GL_GEOMETRY_SHADER_EXT;
using gl::GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED;
using gl::GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB;
using gl::GL_GEOMETRY_VERTICES_OUT_ARB;
using gl::GL_GEOMETRY_VERTICES_OUT_EXT;
using gl::GL_GLOBAL_ALPHA_FACTOR_SUN;
using gl::GL_GLOBAL_ALPHA_SUN;
using gl::GL_GPU_ADDRESS_NV;
using gl::GL_GPU_MEMORY_INFO_CURRENT_AVAILABLE_VIDMEM_NVX;
using gl::GL_GPU_MEMORY_INFO_DEDICATED_VIDMEM_NVX;
using gl::GL_GPU_MEMORY_INFO_EVICTED_MEMORY_NVX;
using gl::GL_GPU_MEMORY_INFO_EVICTION_COUNT_NVX;
using gl::GL_GPU_MEMORY_INFO_TOTAL_AVAILABLE_MEMORY_NVX;
using gl::GL_GREEN_INTEGER_EXT;
using gl::GL_GREEN_MAX_CLAMP_INGR;
using gl::GL_GREEN_MIN_CLAMP_INGR;
using gl::GL_GREEN_NV;
using gl::GL_GUILTY_CONTEXT_RESET;
using gl::GL_GUILTY_CONTEXT_RESET_ARB;
using gl::GL_GUILTY_CONTEXT_RESET_KHR;
using gl::GL_HALF_APPLE;
using gl::GL_HALF_BIAS_NEGATE_NV;
using gl::GL_HALF_BIAS_NORMAL_NV;
using gl::GL_HALF_FLOAT_ARB;
using gl::GL_HALF_FLOAT_NV;
using gl::GL_HANDLE_TYPE_D3D11_IMAGE_EXT;
using gl::GL_HANDLE_TYPE_D3D11_IMAGE_KMT_EXT;
using gl::GL_HANDLE_TYPE_D3D12_FENCE_EXT;
using gl::GL_HANDLE_TYPE_D3D12_RESOURCE_EXT;
using gl::GL_HANDLE_TYPE_D3D12_TILEPOOL_EXT;
using gl::GL_HANDLE_TYPE_OPAQUE_FD_EXT;
using gl::GL_HANDLE_TYPE_OPAQUE_WIN32_EXT;
using gl::GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT;
using gl::GL_HARDLIGHT_KHR;
using gl::GL_HARDLIGHT_NV;
using gl::GL_HARDMIX_NV;
using gl::GL_HI_BIAS_NV;
using gl::GL_HI_SCALE_NV;
using gl::GL_HILO16_NV;
using gl::GL_HILO8_NV;
using gl::GL_HILO_NV;
using gl::GL_HISTOGRAM;
using gl::GL_HISTOGRAM_ALPHA_SIZE;
using gl::GL_HISTOGRAM_ALPHA_SIZE_EXT;
using gl::GL_HISTOGRAM_BLUE_SIZE;
using gl::GL_HISTOGRAM_BLUE_SIZE_EXT;
using gl::GL_HISTOGRAM_EXT;
using gl::GL_HISTOGRAM_FORMAT;
using gl::GL_HISTOGRAM_FORMAT_EXT;
using gl::GL_HISTOGRAM_GREEN_SIZE;
using gl::GL_HISTOGRAM_GREEN_SIZE_EXT;
using gl::GL_HISTOGRAM_LUMINANCE_SIZE;
using gl::GL_HISTOGRAM_LUMINANCE_SIZE_EXT;
using gl::GL_HISTOGRAM_RED_SIZE;
using gl::GL_HISTOGRAM_RED_SIZE_EXT;
using gl::GL_HISTOGRAM_SINK;
using gl::GL_HISTOGRAM_SINK_EXT;
using gl::GL_HISTOGRAM_WIDTH;
using gl::GL_HISTOGRAM_WIDTH_EXT;
using gl::GL_HORIZONTAL_LINE_TO_NV;
using gl::GL_HSL_COLOR_KHR;
using gl::GL_HSL_COLOR_NV;
using gl::GL_HSL_HUE_KHR;
using gl::GL_HSL_HUE_NV;
using gl::GL_HSL_LUMINOSITY_KHR;
using gl::GL_HSL_LUMINOSITY_NV;
using gl::GL_HSL_SATURATION_KHR;
using gl::GL_HSL_SATURATION_NV;
using gl::GL_IDENTITY_NV;
using gl::GL_IGNORE_BORDER_HP;
using gl::GL_IMAGE_1D_ARRAY_EXT;
using gl::GL_IMAGE_1D_EXT;
using gl::GL_IMAGE_2D_ARRAY_EXT;
using gl::GL_IMAGE_2D_EXT;
using gl::GL_IMAGE_2D_MULTISAMPLE_ARRAY_EXT;
using gl::GL_IMAGE_2D_MULTISAMPLE_EXT;
using gl::GL_IMAGE_2D_RECT_EXT;
using gl::GL_IMAGE_3D_EXT;
using gl::GL_IMAGE_BINDING_ACCESS_EXT;
using gl::GL_IMAGE_BINDING_FORMAT_EXT;
using gl::GL_IMAGE_BINDING_LAYER_EXT;
using gl::GL_IMAGE_BINDING_LAYERED_EXT;
using gl::GL_IMAGE_BINDING_LEVEL_EXT;
using gl::GL_IMAGE_BINDING_NAME_EXT;
using gl::GL_IMAGE_BUFFER_EXT;
using gl::GL_IMAGE_CUBE_EXT;
using gl::GL_IMAGE_CUBE_MAP_ARRAY_EXT;
using gl::GL_IMAGE_CUBIC_WEIGHT_HP;
using gl::GL_IMAGE_MAG_FILTER_HP;
using gl::GL_IMAGE_MIN_FILTER_HP;
using gl::GL_IMAGE_ROTATE_ANGLE_HP;
using gl::GL_IMAGE_ROTATE_ORIGIN_X_HP;
using gl::GL_IMAGE_ROTATE_ORIGIN_Y_HP;
using gl::GL_IMAGE_SCALE_X_HP;
using gl::GL_IMAGE_SCALE_Y_HP;
using gl::GL_IMAGE_TRANSFORM_2D_HP;
using gl::GL_IMAGE_TRANSLATE_X_HP;
using gl::GL_IMAGE_TRANSLATE_Y_HP;
using gl::GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES;
using gl::GL_IMPLEMENTATION_COLOR_READ_TYPE_OES;
using gl::GL_INCLUSIVE_EXT;
using gl::GL_INCR_WRAP_EXT;
using gl::GL_INDEX_ARRAY_ADDRESS_NV;
using gl::GL_INDEX_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_INDEX_ARRAY_COUNT_EXT;
using gl::GL_INDEX_ARRAY_EXT;
using gl::GL_INDEX_ARRAY_LENGTH_NV;
using gl::GL_INDEX_ARRAY_LIST_IBM;
using gl::GL_INDEX_ARRAY_LIST_STRIDE_IBM;
using gl::GL_INDEX_ARRAY_POINTER_EXT;
using gl::GL_INDEX_ARRAY_STRIDE_EXT;
using gl::GL_INDEX_ARRAY_TYPE_EXT;
using gl::GL_INDEX_MATERIAL_EXT;
using gl::GL_INDEX_MATERIAL_FACE_EXT;
using gl::GL_INDEX_MATERIAL_PARAMETER_EXT;
using gl::GL_INDEX_TEST_EXT;
using gl::GL_INDEX_TEST_FUNC_EXT;
using gl::GL_INDEX_TEST_REF_EXT;
using gl::GL_INNOCENT_CONTEXT_RESET;
using gl::GL_INNOCENT_CONTEXT_RESET_ARB;
using gl::GL_INNOCENT_CONTEXT_RESET_KHR;
using gl::GL_INSTRUMENT_BUFFER_POINTER_SGIX;
using gl::GL_INSTRUMENT_MEASUREMENTS_SGIX;
using gl::GL_INT16_NV;
using gl::GL_INT16_VEC2_NV;
using gl::GL_INT16_VEC3_NV;
using gl::GL_INT16_VEC4_NV;
using gl::GL_INT64_ARB;
using gl::GL_INT64_NV;
using gl::GL_INT64_VEC2_ARB;
using gl::GL_INT64_VEC2_NV;
using gl::GL_INT64_VEC3_ARB;
using gl::GL_INT64_VEC3_NV;
using gl::GL_INT64_VEC4_ARB;
using gl::GL_INT64_VEC4_NV;
using gl::GL_INT8_NV;
using gl::GL_INT8_VEC2_NV;
using gl::GL_INT8_VEC3_NV;
using gl::GL_INT8_VEC4_NV;
using gl::GL_INT_IMAGE_1D_ARRAY_EXT;
using gl::GL_INT_IMAGE_1D_EXT;
using gl::GL_INT_IMAGE_2D_ARRAY_EXT;
using gl::GL_INT_IMAGE_2D_EXT;
using gl::GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT;
using gl::GL_INT_IMAGE_2D_MULTISAMPLE_EXT;
using gl::GL_INT_IMAGE_2D_RECT_EXT;
using gl::GL_INT_IMAGE_3D_EXT;
using gl::GL_INT_IMAGE_BUFFER_EXT;
using gl::GL_INT_IMAGE_CUBE_EXT;
using gl::GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT;
using gl::GL_INT_SAMPLER_1D_ARRAY_EXT;
using gl::GL_INT_SAMPLER_1D_EXT;
using gl::GL_INT_SAMPLER_2D_ARRAY_EXT;
using gl::GL_INT_SAMPLER_2D_EXT;
using gl::GL_INT_SAMPLER_2D_RECT_EXT;
using gl::GL_INT_SAMPLER_3D_EXT;
using gl::GL_INT_SAMPLER_BUFFER_AMD;
using gl::GL_INT_SAMPLER_BUFFER_EXT;
using gl::GL_INT_SAMPLER_CUBE_EXT;
using gl::GL_INT_SAMPLER_CUBE_MAP_ARRAY_ARB;
using gl::GL_INT_SAMPLER_RENDERBUFFER_NV;
using gl::GL_INT_VEC2_ARB;
using gl::GL_INT_VEC3_ARB;
using gl::GL_INT_VEC4_ARB;
using gl::GL_INTENSITY12_EXT;
using gl::GL_INTENSITY16_EXT;
using gl::GL_INTENSITY16_SNORM;
using gl::GL_INTENSITY16F_ARB;
using gl::GL_INTENSITY16I_EXT;
using gl::GL_INTENSITY16UI_EXT;
using gl::GL_INTENSITY32F_ARB;
using gl::GL_INTENSITY32I_EXT;
using gl::GL_INTENSITY32UI_EXT;
using gl::GL_INTENSITY4_EXT;
using gl::GL_INTENSITY8_EXT;
using gl::GL_INTENSITY8_SNORM;
using gl::GL_INTENSITY8I_EXT;
using gl::GL_INTENSITY8UI_EXT;
using gl::GL_INTENSITY_EXT;
using gl::GL_INTENSITY_FLOAT16_APPLE;
using gl::GL_INTENSITY_FLOAT16_ATI;
using gl::GL_INTENSITY_FLOAT32_APPLE;
using gl::GL_INTENSITY_FLOAT32_ATI;
using gl::GL_INTENSITY_SNORM;
using gl::GL_INTERLACE_OML;
using gl::GL_INTERLACE_READ_INGR;
using gl::GL_INTERLACE_READ_OML;
using gl::GL_INTERLACE_SGIX;
using gl::GL_INTERLEAVED_ATTRIBS_EXT;
using gl::GL_INTERLEAVED_ATTRIBS_NV;
using gl::GL_INTERPOLATE_ARB;
using gl::GL_INTERPOLATE_EXT;
using gl::GL_INVALID_FRAMEBUFFER_OPERATION_EXT;
using gl::GL_INVARIANT_DATATYPE_EXT;
using gl::GL_INVARIANT_EXT;
using gl::GL_INVARIANT_VALUE_EXT;
using gl::GL_INVERSE_NV;
using gl::GL_INVERSE_TRANSPOSE_NV;
using gl::GL_INVERT_OVG_NV;
using gl::GL_INVERT_RGB_NV;
using gl::GL_INVERTED_SCREEN_W_REND;
using gl::GL_IR_INSTRUMENT1_SGIX;
using gl::GL_IUI_N3F_V2F_EXT;
using gl::GL_IUI_N3F_V3F_EXT;
using gl::GL_IUI_V2F_EXT;
using gl::GL_IUI_V3F_EXT;
using gl::GL_LARGE_CCW_ARC_TO_NV;
using gl::GL_LARGE_CW_ARC_TO_NV;
using gl::GL_LAST_VERTEX_CONVENTION_EXT;
using gl::GL_LAST_VIDEO_CAPTURE_STATUS_NV;
using gl::GL_LAYER_NV;
using gl::GL_LAYOUT_COLOR_ATTACHMENT_EXT;
using gl::GL_LAYOUT_DEFAULT_INTEL;
using gl::GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT;
using gl::GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT;
using gl::GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT;
using gl::GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT;
using gl::GL_LAYOUT_GENERAL_EXT;
using gl::GL_LAYOUT_LINEAR_CPU_CACHED_INTEL;
using gl::GL_LAYOUT_LINEAR_INTEL;
using gl::GL_LAYOUT_SHADER_READ_ONLY_EXT;
using gl::GL_LAYOUT_TRANSFER_DST_EXT;
using gl::GL_LAYOUT_TRANSFER_SRC_EXT;
using gl::GL_LERP_ATI;
using gl::GL_LIGHT_ENV_MODE_SGIX;
using gl::GL_LIGHT_MODEL_COLOR_CONTROL_EXT;
using gl::GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE;
using gl::GL_LIGHTEN_KHR;
using gl::GL_LIGHTEN_NV;
using gl::GL_LINE_STRIP_ADJACENCY_ARB;
using gl::GL_LINE_STRIP_ADJACENCY_EXT;
using gl::GL_LINE_TO_NV;
using gl::GL_LINE_WIDTH_COMMAND_NV;
using gl::GL_LINEAR_CLIPMAP_LINEAR_SGIX;
using gl::GL_LINEAR_CLIPMAP_NEAREST_SGIX;
using gl::GL_LINEAR_DETAIL_ALPHA_SGIS;
using gl::GL_LINEAR_DETAIL_COLOR_SGIS;
using gl::GL_LINEAR_DETAIL_SGIS;
using gl::GL_LINEAR_SHARPEN_ALPHA_SGIS;
using gl::GL_LINEAR_SHARPEN_COLOR_SGIS;
using gl::GL_LINEAR_SHARPEN_SGIS;
using gl::GL_LINEAR_TILING_EXT;
using gl::GL_LINEARBURN_NV;
using gl::GL_LINEARDODGE_NV;
using gl::GL_LINEARLIGHT_NV;
using gl::GL_LINES_ADJACENCY_ARB;
using gl::GL_LINES_ADJACENCY_EXT;
using gl::GL_LIST_PRIORITY_SGIX;
using gl::GL_LO_BIAS_NV;
using gl::GL_LO_SCALE_NV;
using gl::GL_LOCAL_CONSTANT_DATATYPE_EXT;
using gl::GL_LOCAL_CONSTANT_EXT;
using gl::GL_LOCAL_CONSTANT_VALUE_EXT;
using gl::GL_LOCAL_EXT;
using gl::GL_LOCATION_COMPONENT;
using gl::GL_LOSE_CONTEXT_ON_RESET;
using gl::GL_LOSE_CONTEXT_ON_RESET_ARB;
using gl::GL_LOSE_CONTEXT_ON_RESET_KHR;
using gl::GL_LUMINANCE12_ALPHA12_EXT;
using gl::GL_LUMINANCE12_ALPHA4_EXT;
using gl::GL_LUMINANCE12_EXT;
using gl::GL_LUMINANCE16_ALPHA16_EXT;
using gl::GL_LUMINANCE16_ALPHA16_SNORM;
using gl::GL_LUMINANCE16_EXT;
using gl::GL_LUMINANCE16_SNORM;
using gl::GL_LUMINANCE16F_ARB;
using gl::GL_LUMINANCE16F_EXT;
using gl::GL_LUMINANCE16I_EXT;
using gl::GL_LUMINANCE16UI_EXT;
using gl::GL_LUMINANCE32F_ARB;
using gl::GL_LUMINANCE32F_EXT;
using gl::GL_LUMINANCE32I_EXT;
using gl::GL_LUMINANCE32UI_EXT;
using gl::GL_LUMINANCE4_ALPHA4_EXT;
using gl::GL_LUMINANCE4_EXT;
using gl::GL_LUMINANCE6_ALPHA2_EXT;
using gl::GL_LUMINANCE8_ALPHA8_EXT;
using gl::GL_LUMINANCE8_ALPHA8_SNORM;
using gl::GL_LUMINANCE8_EXT;
using gl::GL_LUMINANCE8_SNORM;
using gl::GL_LUMINANCE8I_EXT;
using gl::GL_LUMINANCE8UI_EXT;
using gl::GL_LUMINANCE_ALPHA16F_ARB;
using gl::GL_LUMINANCE_ALPHA16F_EXT;
using gl::GL_LUMINANCE_ALPHA16I_EXT;
using gl::GL_LUMINANCE_ALPHA16UI_EXT;
using gl::GL_LUMINANCE_ALPHA32F_ARB;
using gl::GL_LUMINANCE_ALPHA32F_EXT;
using gl::GL_LUMINANCE_ALPHA32I_EXT;
using gl::GL_LUMINANCE_ALPHA32UI_EXT;
using gl::GL_LUMINANCE_ALPHA8I_EXT;
using gl::GL_LUMINANCE_ALPHA8UI_EXT;
using gl::GL_LUMINANCE_ALPHA_FLOAT16_APPLE;
using gl::GL_LUMINANCE_ALPHA_FLOAT16_ATI;
using gl::GL_LUMINANCE_ALPHA_FLOAT32_APPLE;
using gl::GL_LUMINANCE_ALPHA_FLOAT32_ATI;
using gl::GL_LUMINANCE_ALPHA_INTEGER_EXT;
using gl::GL_LUMINANCE_ALPHA_SNORM;
using gl::GL_LUMINANCE_FLOAT16_APPLE;
using gl::GL_LUMINANCE_FLOAT16_ATI;
using gl::GL_LUMINANCE_FLOAT32_APPLE;
using gl::GL_LUMINANCE_FLOAT32_ATI;
using gl::GL_LUMINANCE_INTEGER_EXT;
using gl::GL_LUMINANCE_SNORM;
using gl::GL_MAD_ATI;
using gl::GL_MAGNITUDE_BIAS_NV;
using gl::GL_MAGNITUDE_SCALE_NV;
using gl::GL_MAP1_BINORMAL_EXT;
using gl::GL_MAP1_TANGENT_EXT;
using gl::GL_MAP1_VERTEX_ATTRIB0_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB10_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB11_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB12_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB13_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB14_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB15_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB1_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB2_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB3_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB4_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB5_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB6_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB7_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB8_4_NV;
using gl::GL_MAP1_VERTEX_ATTRIB9_4_NV;
using gl::GL_MAP2_BINORMAL_EXT;
using gl::GL_MAP2_TANGENT_EXT;
using gl::GL_MAP2_VERTEX_ATTRIB0_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB10_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB11_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB12_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB13_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB14_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB15_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB1_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB2_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB3_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB4_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB5_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB6_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB7_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB8_4_NV;
using gl::GL_MAP2_VERTEX_ATTRIB9_4_NV;
using gl::GL_MAP_ATTRIB_U_ORDER_NV;
using gl::GL_MAP_ATTRIB_V_ORDER_NV;
using gl::GL_MAP_TESSELLATION_NV;
using gl::GL_MATERIAL_SIDE_HINT_PGI;
using gl::GL_MATRIX0_ARB;
using gl::GL_MATRIX0_NV;
using gl::GL_MATRIX10_ARB;
using gl::GL_MATRIX11_ARB;
using gl::GL_MATRIX12_ARB;
using gl::GL_MATRIX13_ARB;
using gl::GL_MATRIX14_ARB;
using gl::GL_MATRIX15_ARB;
using gl::GL_MATRIX16_ARB;
using gl::GL_MATRIX17_ARB;
using gl::GL_MATRIX18_ARB;
using gl::GL_MATRIX19_ARB;
using gl::GL_MATRIX1_ARB;
using gl::GL_MATRIX1_NV;
using gl::GL_MATRIX20_ARB;
using gl::GL_MATRIX21_ARB;
using gl::GL_MATRIX22_ARB;
using gl::GL_MATRIX23_ARB;
using gl::GL_MATRIX24_ARB;
using gl::GL_MATRIX25_ARB;
using gl::GL_MATRIX26_ARB;
using gl::GL_MATRIX27_ARB;
using gl::GL_MATRIX28_ARB;
using gl::GL_MATRIX29_ARB;
using gl::GL_MATRIX2_ARB;
using gl::GL_MATRIX2_NV;
using gl::GL_MATRIX30_ARB;
using gl::GL_MATRIX31_ARB;
using gl::GL_MATRIX3_ARB;
using gl::GL_MATRIX3_NV;
using gl::GL_MATRIX4_ARB;
using gl::GL_MATRIX4_NV;
using gl::GL_MATRIX5_ARB;
using gl::GL_MATRIX5_NV;
using gl::GL_MATRIX6_ARB;
using gl::GL_MATRIX6_NV;
using gl::GL_MATRIX7_ARB;
using gl::GL_MATRIX7_NV;
using gl::GL_MATRIX8_ARB;
using gl::GL_MATRIX9_ARB;
using gl::GL_MATRIX_EXT;
using gl::GL_MATRIX_INDEX_ARRAY_ARB;
using gl::GL_MATRIX_INDEX_ARRAY_POINTER_ARB;
using gl::GL_MATRIX_INDEX_ARRAY_SIZE_ARB;
using gl::GL_MATRIX_INDEX_ARRAY_STRIDE_ARB;
using gl::GL_MATRIX_INDEX_ARRAY_TYPE_ARB;
using gl::GL_MATRIX_PALETTE_ARB;
using gl::GL_MAX_3D_TEXTURE_SIZE_EXT;
using gl::GL_MAX_4D_TEXTURE_SIZE_SGIS;
using gl::GL_MAX_ACTIVE_LIGHTS_SGIX;
using gl::GL_MAX_ARRAY_TEXTURE_LAYERS_EXT;
using gl::GL_MAX_ASYNC_DRAW_PIXELS_SGIX;
using gl::GL_MAX_ASYNC_HISTOGRAM_SGIX;
using gl::GL_MAX_ASYNC_READ_PIXELS_SGIX;
using gl::GL_MAX_ASYNC_TEX_IMAGE_SGIX;
using gl::GL_MAX_BINDABLE_UNIFORM_SIZE_EXT;
using gl::GL_MAX_CLIPMAP_DEPTH_SGIX;
using gl::GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX;
using gl::GL_MAX_COARSE_FRAGMENT_SAMPLES_NV;
using gl::GL_MAX_COLOR_ATTACHMENTS_EXT;
using gl::GL_MAX_COLOR_FRAMEBUFFER_SAMPLES_AMD;
using gl::GL_MAX_COLOR_FRAMEBUFFER_STORAGE_SAMPLES_AMD;
using gl::GL_MAX_COLOR_MATRIX_STACK_DEPTH;
using gl::GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI;
using gl::GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES;
using gl::GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS_EXT;
using gl::GL_MAX_COMBINED_MESH_UNIFORM_COMPONENTS_NV;
using gl::GL_MAX_COMBINED_TASK_UNIFORM_COMPONENTS_NV;
using gl::GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB;
using gl::GL_MAX_COMPUTE_FIXED_GROUP_INVOCATIONS_ARB;
using gl::GL_MAX_COMPUTE_FIXED_GROUP_SIZE_ARB;
using gl::GL_MAX_COMPUTE_VARIABLE_GROUP_INVOCATIONS_ARB;
using gl::GL_MAX_COMPUTE_VARIABLE_GROUP_SIZE_ARB;
using gl::GL_MAX_CONVOLUTION_HEIGHT;
using gl::GL_MAX_CONVOLUTION_HEIGHT_EXT;
using gl::GL_MAX_CONVOLUTION_WIDTH;
using gl::GL_MAX_CONVOLUTION_WIDTH_EXT;
using gl::GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB;
using gl::GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT;
using gl::GL_MAX_CULL_DISTANCES;
using gl::GL_MAX_DEBUG_GROUP_STACK_DEPTH_KHR;
using gl::GL_MAX_DEBUG_LOGGED_MESSAGES_AMD;
using gl::GL_MAX_DEBUG_LOGGED_MESSAGES_ARB;
using gl::GL_MAX_DEBUG_LOGGED_MESSAGES_KHR;
using gl::GL_MAX_DEBUG_MESSAGE_LENGTH_AMD;
using gl::GL_MAX_DEBUG_MESSAGE_LENGTH_ARB;
using gl::GL_MAX_DEBUG_MESSAGE_LENGTH_KHR;
using gl::GL_MAX_DEEP_3D_TEXTURE_DEPTH_NV;
using gl::GL_MAX_DEEP_3D_TEXTURE_WIDTH_HEIGHT_NV;
using gl::GL_MAX_DEFORMATION_ORDER_SGIX;
using gl::GL_MAX_DEPTH_STENCIL_FRAMEBUFFER_SAMPLES_AMD;
using gl::GL_MAX_DETACHED_BUFFERS_NV;
using gl::GL_MAX_DETACHED_TEXTURES_NV;
using gl::GL_MAX_DRAW_BUFFERS_ARB;
using gl::GL_MAX_DRAW_BUFFERS_ATI;
using gl::GL_MAX_DRAW_MESH_TASKS_COUNT_NV;
using gl::GL_MAX_ELEMENTS_INDICES_EXT;
using gl::GL_MAX_ELEMENTS_VERTICES_EXT;
using gl::GL_MAX_EXT;
using gl::GL_MAX_FOG_FUNC_POINTS_SGIS;
using gl::GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT;
using gl::GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_NV;
using gl::GL_MAX_FRAGMENT_LIGHTS_SGIX;
using gl::GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV;
using gl::GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB;
using gl::GL_MAX_FRAMEZOOM_FACTOR_SGIX;
using gl::GL_MAX_GENERAL_COMBINERS_NV;
using gl::GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT;
using gl::GL_MAX_GEOMETRY_OUTPUT_VERTICES_ARB;
using gl::GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT;
using gl::GL_MAX_GEOMETRY_PROGRAM_INVOCATIONS_NV;
using gl::GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_ARB;
using gl::GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT;
using gl::GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_ARB;
using gl::GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT;
using gl::GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_ARB;
using gl::GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT;
using gl::GL_MAX_GEOMETRY_VARYING_COMPONENTS_ARB;
using gl::GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT;
using gl::GL_MAX_IMAGE_SAMPLES_EXT;
using gl::GL_MAX_IMAGE_UNITS_EXT;
using gl::GL_MAX_LABEL_LENGTH_KHR;
using gl::GL_MAX_LGPU_GPUS_NVX;
using gl::GL_MAX_MAP_TESSELLATION_NV;
using gl::GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB;
using gl::GL_MAX_MESH_ATOMIC_COUNTER_BUFFERS_NV;
using gl::GL_MAX_MESH_ATOMIC_COUNTERS_NV;
using gl::GL_MAX_MESH_IMAGE_UNIFORMS_NV;
using gl::GL_MAX_MESH_OUTPUT_PRIMITIVES_NV;
using gl::GL_MAX_MESH_OUTPUT_VERTICES_NV;
using gl::GL_MAX_MESH_SHADER_STORAGE_BLOCKS_NV;
using gl::GL_MAX_MESH_TEXTURE_IMAGE_UNITS_NV;
using gl::GL_MAX_MESH_TOTAL_MEMORY_SIZE_NV;
using gl::GL_MAX_MESH_UNIFORM_BLOCKS_NV;
using gl::GL_MAX_MESH_UNIFORM_COMPONENTS_NV;
using gl::GL_MAX_MESH_VIEWS_NV;
using gl::GL_MAX_MESH_WORK_GROUP_INVOCATIONS_NV;
using gl::GL_MAX_MESH_WORK_GROUP_SIZE_NV;
using gl::GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV;
using gl::GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT;
using gl::GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT;
using gl::GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT;
using gl::GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT;
using gl::GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT;
using gl::GL_MAX_PALETTE_MATRICES_ARB;
using gl::GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT;
using gl::GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI;
using gl::GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB;
using gl::GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB;
using gl::GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV;
using gl::GL_MAX_PROGRAM_ATTRIBS_ARB;
using gl::GL_MAX_PROGRAM_CALL_DEPTH_NV;
using gl::GL_MAX_PROGRAM_ENV_PARAMETERS_ARB;
using gl::GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV;
using gl::GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV;
using gl::GL_MAX_PROGRAM_GENERIC_RESULTS_NV;
using gl::GL_MAX_PROGRAM_IF_DEPTH_NV;
using gl::GL_MAX_PROGRAM_INSTRUCTIONS_ARB;
using gl::GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB;
using gl::GL_MAX_PROGRAM_LOOP_COUNT_NV;
using gl::GL_MAX_PROGRAM_LOOP_DEPTH_NV;
using gl::GL_MAX_PROGRAM_MATRICES_ARB;
using gl::GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB;
using gl::GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB;
using gl::GL_MAX_PROGRAM_OUTPUT_VERTICES_NV;
using gl::GL_MAX_PROGRAM_PARAMETER_BUFFER_BINDINGS_NV;
using gl::GL_MAX_PROGRAM_PARAMETER_BUFFER_SIZE_NV;
using gl::GL_MAX_PROGRAM_PARAMETERS_ARB;
using gl::GL_MAX_PROGRAM_PATCH_ATTRIBS_NV;
using gl::GL_MAX_PROGRAM_RESULT_COMPONENTS_NV;
using gl::GL_MAX_PROGRAM_SUBROUTINE_NUM_NV;
using gl::GL_MAX_PROGRAM_SUBROUTINE_PARAMETERS_NV;
using gl::GL_MAX_PROGRAM_TEMPORARIES_ARB;
using gl::GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB;
using gl::GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB;
using gl::GL_MAX_PROGRAM_TEXEL_OFFSET_EXT;
using gl::GL_MAX_PROGRAM_TEXEL_OFFSET_NV;
using gl::GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS_ARB;
using gl::GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_ARB;
using gl::GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_NV;
using gl::GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV;
using gl::GL_MAX_RASTER_SAMPLES_EXT;
using gl::GL_MAX_RATIONAL_EVAL_ORDER_NV;
using gl::GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB;
using gl::GL_MAX_RECTANGLE_TEXTURE_SIZE_NV;
using gl::GL_MAX_RENDERBUFFER_SIZE_EXT;
using gl::GL_MAX_SAMPLE_MASK_WORDS_NV;
using gl::GL_MAX_SAMPLES_EXT;
using gl::GL_MAX_SHADER_BUFFER_ADDRESS_NV;
using gl::GL_MAX_SHADER_COMPILER_THREADS_ARB;
using gl::GL_MAX_SHADER_COMPILER_THREADS_KHR;
using gl::GL_MAX_SHININESS_NV;
using gl::GL_MAX_SPARSE_3D_TEXTURE_SIZE_AMD;
using gl::GL_MAX_SPARSE_3D_TEXTURE_SIZE_ARB;
using gl::GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS;
using gl::GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS_ARB;
using gl::GL_MAX_SPARSE_TEXTURE_SIZE_AMD;
using gl::GL_MAX_SPARSE_TEXTURE_SIZE_ARB;
using gl::GL_MAX_SPOT_EXPONENT_NV;
using gl::GL_MAX_SUBPIXEL_PRECISION_BIAS_BITS_NV;
using gl::GL_MAX_TASK_ATOMIC_COUNTER_BUFFERS_NV;
using gl::GL_MAX_TASK_ATOMIC_COUNTERS_NV;
using gl::GL_MAX_TASK_IMAGE_UNIFORMS_NV;
using gl::GL_MAX_TASK_OUTPUT_COUNT_NV;
using gl::GL_MAX_TASK_SHADER_STORAGE_BLOCKS_NV;
using gl::GL_MAX_TASK_TEXTURE_IMAGE_UNITS_NV;
using gl::GL_MAX_TASK_TOTAL_MEMORY_SIZE_NV;
using gl::GL_MAX_TASK_UNIFORM_BLOCKS_NV;
using gl::GL_MAX_TASK_UNIFORM_COMPONENTS_NV;
using gl::GL_MAX_TASK_WORK_GROUP_INVOCATIONS_NV;
using gl::GL_MAX_TASK_WORK_GROUP_SIZE_NV;
using gl::GL_MAX_TEXTURE_BUFFER_SIZE_ARB;
using gl::GL_MAX_TEXTURE_BUFFER_SIZE_EXT;
using gl::GL_MAX_TEXTURE_COORDS_ARB;
using gl::GL_MAX_TEXTURE_COORDS_NV;
using gl::GL_MAX_TEXTURE_IMAGE_UNITS_ARB;
using gl::GL_MAX_TEXTURE_IMAGE_UNITS_NV;
using gl::GL_MAX_TEXTURE_LOD_BIAS_EXT;
using gl::GL_MAX_TEXTURE_MAX_ANISOTROPY;
using gl::GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT;
using gl::GL_MAX_TEXTURE_UNITS_ARB;
using gl::GL_MAX_TIMELINE_SEMAPHORE_VALUE_DIFFERENCE_NV;
using gl::GL_MAX_TRACK_MATRICES_NV;
using gl::GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV;
using gl::GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT;
using gl::GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_NV;
using gl::GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT;
using gl::GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_NV;
using gl::GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT;
using gl::GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_NV;
using gl::GL_MAX_VARYING_COMPONENTS_EXT;
using gl::GL_MAX_VARYING_FLOATS_ARB;
using gl::GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV;
using gl::GL_MAX_VERTEX_ATTRIB_STRIDE;
using gl::GL_MAX_VERTEX_ATTRIBS_ARB;
using gl::GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT;
using gl::GL_MAX_VERTEX_HINT_PGI;
using gl::GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT;
using gl::GL_MAX_VERTEX_SHADER_INVARIANTS_EXT;
using gl::GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT;
using gl::GL_MAX_VERTEX_SHADER_LOCALS_EXT;
using gl::GL_MAX_VERTEX_SHADER_VARIANTS_EXT;
using gl::GL_MAX_VERTEX_STREAMS_ATI;
using gl::GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB;
using gl::GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB;
using gl::GL_MAX_VERTEX_UNITS_ARB;
using gl::GL_MAX_VERTEX_VARYING_COMPONENTS_ARB;
using gl::GL_MAX_VERTEX_VARYING_COMPONENTS_EXT;
using gl::GL_MAX_VIEWS_OVR;
using gl::GL_MAX_WINDOW_RECTANGLES_EXT;
using gl::GL_MEMORY_ATTACHABLE_ALIGNMENT_NV;
using gl::GL_MEMORY_ATTACHABLE_NV;
using gl::GL_MEMORY_ATTACHABLE_SIZE_NV;
using gl::GL_MESH_OUTPUT_PER_PRIMITIVE_GRANULARITY_NV;
using gl::GL_MESH_OUTPUT_PER_VERTEX_GRANULARITY_NV;
using gl::GL_MESH_OUTPUT_TYPE_NV;
using gl::GL_MESH_PRIMITIVES_OUT_NV;
using gl::GL_MESH_SHADER_NV;
using gl::GL_MESH_SUBROUTINE_NV;
using gl::GL_MESH_SUBROUTINE_UNIFORM_NV;
using gl::GL_MESH_VERTICES_OUT_NV;
using gl::GL_MESH_WORK_GROUP_SIZE_NV;
using gl::GL_MIN_EXT;
using gl::GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_NV;
using gl::GL_MIN_LOD_WARNING_AMD;
using gl::GL_MIN_PROGRAM_TEXEL_OFFSET_EXT;
using gl::GL_MIN_PROGRAM_TEXEL_OFFSET_NV;
using gl::GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_ARB;
using gl::GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_NV;
using gl::GL_MIN_SAMPLE_SHADING_VALUE_ARB;
using gl::GL_MIN_SPARSE_LEVEL_AMD;
using gl::GL_MINMAX;
using gl::GL_MINMAX_EXT;
using gl::GL_MINMAX_FORMAT;
using gl::GL_MINMAX_FORMAT_EXT;
using gl::GL_MINMAX_SINK;
using gl::GL_MINMAX_SINK_EXT;
using gl::GL_MINUS_CLAMPED_NV;
using gl::GL_MINUS_NV;
using gl::GL_MIRROR_CLAMP_ATI;
using gl::GL_MIRROR_CLAMP_EXT;
using gl::GL_MIRROR_CLAMP_TO_BORDER_EXT;
using gl::GL_MIRROR_CLAMP_TO_EDGE;
using gl::GL_MIRROR_CLAMP_TO_EDGE_ATI;
using gl::GL_MIRROR_CLAMP_TO_EDGE_EXT;
using gl::GL_MIRRORED_REPEAT_ARB;
using gl::GL_MIRRORED_REPEAT_IBM;
using gl::GL_MITER_REVERT_NV;
using gl::GL_MITER_TRUNCATE_NV;
using gl::GL_MIXED_DEPTH_SAMPLES_SUPPORTED_NV;
using gl::GL_MIXED_STENCIL_SAMPLES_SUPPORTED_NV;
using gl::GL_MODELVIEW0_ARB;
using gl::GL_MODELVIEW0_EXT;
using gl::GL_MODELVIEW0_MATRIX_EXT;
using gl::GL_MODELVIEW0_STACK_DEPTH_EXT;
using gl::GL_MODELVIEW10_ARB;
using gl::GL_MODELVIEW11_ARB;
using gl::GL_MODELVIEW12_ARB;
using gl::GL_MODELVIEW13_ARB;
using gl::GL_MODELVIEW14_ARB;
using gl::GL_MODELVIEW15_ARB;
using gl::GL_MODELVIEW16_ARB;
using gl::GL_MODELVIEW17_ARB;
using gl::GL_MODELVIEW18_ARB;
using gl::GL_MODELVIEW19_ARB;
using gl::GL_MODELVIEW1_ARB;
using gl::GL_MODELVIEW1_EXT;
using gl::GL_MODELVIEW1_MATRIX_EXT;
using gl::GL_MODELVIEW1_STACK_DEPTH_EXT;
using gl::GL_MODELVIEW20_ARB;
using gl::GL_MODELVIEW21_ARB;
using gl::GL_MODELVIEW22_ARB;
using gl::GL_MODELVIEW23_ARB;
using gl::GL_MODELVIEW24_ARB;
using gl::GL_MODELVIEW25_ARB;
using gl::GL_MODELVIEW26_ARB;
using gl::GL_MODELVIEW27_ARB;
using gl::GL_MODELVIEW28_ARB;
using gl::GL_MODELVIEW29_ARB;
using gl::GL_MODELVIEW2_ARB;
using gl::GL_MODELVIEW30_ARB;
using gl::GL_MODELVIEW31_ARB;
using gl::GL_MODELVIEW3_ARB;
using gl::GL_MODELVIEW4_ARB;
using gl::GL_MODELVIEW5_ARB;
using gl::GL_MODELVIEW6_ARB;
using gl::GL_MODELVIEW7_ARB;
using gl::GL_MODELVIEW8_ARB;
using gl::GL_MODELVIEW9_ARB;
using gl::GL_MODELVIEW_PROJECTION_NV;
using gl::GL_MODULATE_ADD_ATI;
using gl::GL_MODULATE_SIGNED_ADD_ATI;
using gl::GL_MODULATE_SUBTRACT_ATI;
using gl::GL_MOV_ATI;
using gl::GL_MOVE_TO_CONTINUES_NV;
using gl::GL_MOVE_TO_NV;
using gl::GL_MOVE_TO_RESETS_NV;
using gl::GL_MUL_ATI;
using gl::GL_MULTICAST_GPUS_NV;
using gl::GL_MULTICAST_PROGRAMMABLE_SAMPLE_LOCATION_NV;
using gl::GL_MULTIPLY_KHR;
using gl::GL_MULTIPLY_NV;
using gl::GL_MULTISAMPLE_3DFX;
using gl::GL_MULTISAMPLE_ARB;
using gl::GL_MULTISAMPLE_COVERAGE_MODES_NV;
using gl::GL_MULTISAMPLE_EXT;
using gl::GL_MULTISAMPLE_FILTER_HINT_NV;
using gl::GL_MULTISAMPLE_LINE_WIDTH_GRANULARITY_ARB;
using gl::GL_MULTISAMPLE_LINE_WIDTH_RANGE_ARB;
using gl::GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT;
using gl::GL_MULTISAMPLE_SGIS;
using gl::GL_MULTISAMPLES_NV;
using gl::GL_MVP_MATRIX_EXT;
using gl::GL_NAMED_STRING_LENGTH_ARB;
using gl::GL_NAMED_STRING_TYPE_ARB;
using gl::GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI;
using gl::GL_NATIVE_GRAPHICS_END_HINT_PGI;
using gl::GL_NATIVE_GRAPHICS_HANDLE_PGI;
using gl::GL_NEAREST_CLIPMAP_LINEAR_SGIX;
using gl::GL_NEAREST_CLIPMAP_NEAREST_SGIX;
using gl::GL_NEGATIVE_ONE_EXT;
using gl::GL_NEGATIVE_ONE_TO_ONE;
using gl::GL_NEGATIVE_W_EXT;
using gl::GL_NEGATIVE_X_EXT;
using gl::GL_NEGATIVE_Y_EXT;
using gl::GL_NEGATIVE_Z_EXT;
using gl::GL_NEXT_BUFFER_NV;
using gl::GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV;
using gl::GL_NO_RESET_NOTIFICATION;
using gl::GL_NO_RESET_NOTIFICATION_ARB;
using gl::GL_NO_RESET_NOTIFICATION_KHR;
using gl::GL_NOP_COMMAND_NV;
using gl::GL_NORMAL_ARRAY_ADDRESS_NV;
using gl::GL_NORMAL_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_NORMAL_ARRAY_COUNT_EXT;
using gl::GL_NORMAL_ARRAY_EXT;
using gl::GL_NORMAL_ARRAY_LENGTH_NV;
using gl::GL_NORMAL_ARRAY_LIST_IBM;
using gl::GL_NORMAL_ARRAY_LIST_STRIDE_IBM;
using gl::GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL;
using gl::GL_NORMAL_ARRAY_POINTER_EXT;
using gl::GL_NORMAL_ARRAY_STRIDE_EXT;
using gl::GL_NORMAL_ARRAY_TYPE_EXT;
using gl::GL_NORMAL_MAP_ARB;
using gl::GL_NORMAL_MAP_EXT;
using gl::GL_NORMAL_MAP_NV;
using gl::GL_NORMALIZED_RANGE_EXT;
using gl::GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB;
using gl::GL_NUM_DEVICE_UUIDS_EXT;
using gl::GL_NUM_FILL_STREAMS_NV;
using gl::GL_NUM_FRAGMENT_CONSTANTS_ATI;
using gl::GL_NUM_FRAGMENT_REGISTERS_ATI;
using gl::GL_NUM_GENERAL_COMBINERS_NV;
using gl::GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI;
using gl::GL_NUM_INSTRUCTIONS_PER_PASS_ATI;
using gl::GL_NUM_INSTRUCTIONS_TOTAL_ATI;
using gl::GL_NUM_LOOPBACK_COMPONENTS_ATI;
using gl::GL_NUM_PASSES_ATI;
using gl::GL_NUM_SPARSE_LEVELS_ARB;
using gl::GL_NUM_SPIR_V_EXTENSIONS;
using gl::GL_NUM_SUPPORTED_MULTISAMPLE_MODES_AMD;
using gl::GL_NUM_TILING_TYPES_EXT;
using gl::GL_NUM_VIDEO_CAPTURE_STREAMS_NV;
using gl::GL_NUM_VIRTUAL_PAGE_SIZES_ARB;
using gl::GL_NUM_WINDOW_RECTANGLES_EXT;
using gl::GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB;
using gl::GL_OBJECT_ACTIVE_ATTRIBUTES_ARB;
using gl::GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB;
using gl::GL_OBJECT_ACTIVE_UNIFORMS_ARB;
using gl::GL_OBJECT_ATTACHED_OBJECTS_ARB;
using gl::GL_OBJECT_BUFFER_SIZE_ATI;
using gl::GL_OBJECT_BUFFER_USAGE_ATI;
using gl::GL_OBJECT_COMPILE_STATUS_ARB;
using gl::GL_OBJECT_DELETE_STATUS_ARB;
using gl::GL_OBJECT_DISTANCE_TO_LINE_SGIS;
using gl::GL_OBJECT_DISTANCE_TO_POINT_SGIS;
using gl::GL_OBJECT_INFO_LOG_LENGTH_ARB;
using gl::GL_OBJECT_LINE_SGIS;
using gl::GL_OBJECT_LINEAR_NV;
using gl::GL_OBJECT_LINK_STATUS_ARB;
using gl::GL_OBJECT_POINT_SGIS;
using gl::GL_OBJECT_SHADER_SOURCE_LENGTH_ARB;
using gl::GL_OBJECT_SUBTYPE_ARB;
using gl::GL_OBJECT_TYPE_ARB;
using gl::GL_OBJECT_VALIDATE_STATUS_ARB;
using gl::GL_OCCLUSION_QUERY_EVENT_MASK_AMD;
using gl::GL_OCCLUSION_TEST_HP;
using gl::GL_OCCLUSION_TEST_RESULT_HP;
using gl::GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV;
using gl::GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV;
using gl::GL_OFFSET_HILO_TEXTURE_2D_NV;
using gl::GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV;
using gl::GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV;
using gl::GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV;
using gl::GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV;
using gl::GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV;
using gl::GL_OFFSET_TEXTURE_2D_BIAS_NV;
using gl::GL_OFFSET_TEXTURE_2D_MATRIX_NV;
using gl::GL_OFFSET_TEXTURE_2D_NV;
using gl::GL_OFFSET_TEXTURE_2D_SCALE_NV;
using gl::GL_OFFSET_TEXTURE_BIAS_NV;
using gl::GL_OFFSET_TEXTURE_MATRIX_NV;
using gl::GL_OFFSET_TEXTURE_RECTANGLE_NV;
using gl::GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV;
using gl::GL_OFFSET_TEXTURE_SCALE_NV;
using gl::GL_ONE_EXT;
using gl::GL_ONE_MINUS_CONSTANT_ALPHA_EXT;
using gl::GL_ONE_MINUS_CONSTANT_COLOR_EXT;
using gl::GL_OP_ADD_EXT;
using gl::GL_OP_CLAMP_EXT;
using gl::GL_OP_CROSS_PRODUCT_EXT;
using gl::GL_OP_DOT3_EXT;
using gl::GL_OP_DOT4_EXT;
using gl::GL_OP_EXP_BASE_2_EXT;
using gl::GL_OP_FLOOR_EXT;
using gl::GL_OP_FRAC_EXT;
using gl::GL_OP_INDEX_EXT;
using gl::GL_OP_LOG_BASE_2_EXT;
using gl::GL_OP_MADD_EXT;
using gl::GL_OP_MAX_EXT;
using gl::GL_OP_MIN_EXT;
using gl::GL_OP_MOV_EXT;
using gl::GL_OP_MUL_EXT;
using gl::GL_OP_MULTIPLY_MATRIX_EXT;
using gl::GL_OP_NEGATE_EXT;
using gl::GL_OP_POWER_EXT;
using gl::GL_OP_RECIP_EXT;
using gl::GL_OP_RECIP_SQRT_EXT;
using gl::GL_OP_ROUND_EXT;
using gl::GL_OP_SET_GE_EXT;
using gl::GL_OP_SET_LT_EXT;
using gl::GL_OP_SUB_EXT;
using gl::GL_OPERAND0_ALPHA_ARB;
using gl::GL_OPERAND0_ALPHA_EXT;
using gl::GL_OPERAND0_RGB_ARB;
using gl::GL_OPERAND0_RGB_EXT;
using gl::GL_OPERAND1_ALPHA_ARB;
using gl::GL_OPERAND1_ALPHA_EXT;
using gl::GL_OPERAND1_RGB_ARB;
using gl::GL_OPERAND1_RGB_EXT;
using gl::GL_OPERAND2_ALPHA_ARB;
using gl::GL_OPERAND2_ALPHA_EXT;
using gl::GL_OPERAND2_RGB_ARB;
using gl::GL_OPERAND2_RGB_EXT;
using gl::GL_OPERAND3_ALPHA_NV;
using gl::GL_OPERAND3_RGB_NV;
using gl::GL_OPTIMAL_TILING_EXT;
using gl::GL_OUTPUT_COLOR0_EXT;
using gl::GL_OUTPUT_COLOR1_EXT;
using gl::GL_OUTPUT_FOG_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD0_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD10_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD11_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD12_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD13_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD14_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD15_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD16_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD17_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD18_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD19_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD1_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD20_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD21_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD22_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD23_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD24_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD25_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD26_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD27_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD28_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD29_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD2_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD30_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD31_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD3_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD4_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD5_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD6_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD7_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD8_EXT;
using gl::GL_OUTPUT_TEXTURE_COORD9_EXT;
using gl::GL_OUTPUT_VERTEX_EXT;
using gl::GL_OVERLAY_KHR;
using gl::GL_OVERLAY_NV;
using gl::GL_PACK_CMYK_HINT_EXT;
using gl::GL_PACK_IMAGE_DEPTH_SGIS;
using gl::GL_PACK_IMAGE_HEIGHT_EXT;
using gl::GL_PACK_INVERT_MESA;
using gl::GL_PACK_RESAMPLE_OML;
using gl::GL_PACK_RESAMPLE_SGIX;
using gl::GL_PACK_ROW_BYTES_APPLE;
using gl::GL_PACK_SKIP_IMAGES_EXT;
using gl::GL_PACK_SKIP_VOLUMES_SGIS;
using gl::GL_PACK_SUBSAMPLE_RATE_SGIX;
using gl::GL_PALETTE4_R5_G6_B5_OES;
using gl::GL_PALETTE4_RGB5_A1_OES;
using gl::GL_PALETTE4_RGB8_OES;
using gl::GL_PALETTE4_RGBA4_OES;
using gl::GL_PALETTE4_RGBA8_OES;
using gl::GL_PALETTE8_R5_G6_B5_OES;
using gl::GL_PALETTE8_RGB5_A1_OES;
using gl::GL_PALETTE8_RGB8_OES;
using gl::GL_PALETTE8_RGBA4_OES;
using gl::GL_PALETTE8_RGBA8_OES;
using gl::GL_PARALLEL_ARRAYS_INTEL;
using gl::GL_PARAMETER_BUFFER;
using gl::GL_PARAMETER_BUFFER_ARB;
using gl::GL_PARAMETER_BUFFER_BINDING;
using gl::GL_PARAMETER_BUFFER_BINDING_ARB;
using gl::GL_PARTIAL_SUCCESS_NV;
using gl::GL_PASS_THROUGH_NV;
using gl::GL_PATH_CLIENT_LENGTH_NV;
using gl::GL_PATH_COMMAND_COUNT_NV;
using gl::GL_PATH_COMPUTED_LENGTH_NV;
using gl::GL_PATH_COORD_COUNT_NV;
using gl::GL_PATH_COVER_DEPTH_FUNC_NV;
using gl::GL_PATH_DASH_ARRAY_COUNT_NV;
using gl::GL_PATH_DASH_CAPS_NV;
using gl::GL_PATH_DASH_OFFSET_NV;
using gl::GL_PATH_DASH_OFFSET_RESET_NV;
using gl::GL_PATH_END_CAPS_NV;
using gl::GL_PATH_ERROR_POSITION_NV;
using gl::GL_PATH_FILL_BOUNDING_BOX_NV;
using gl::GL_PATH_FILL_COVER_MODE_NV;
using gl::GL_PATH_FILL_MASK_NV;
using gl::GL_PATH_FILL_MODE_NV;
using gl::GL_PATH_FOG_GEN_MODE_NV;
using gl::GL_PATH_FORMAT_PS_NV;
using gl::GL_PATH_FORMAT_SVG_NV;
using gl::GL_PATH_GEN_COEFF_NV;
using gl::GL_PATH_GEN_COLOR_FORMAT_NV;
using gl::GL_PATH_GEN_COMPONENTS_NV;
using gl::GL_PATH_GEN_MODE_NV;
using gl::GL_PATH_INITIAL_DASH_CAP_NV;
using gl::GL_PATH_INITIAL_END_CAP_NV;
using gl::GL_PATH_JOIN_STYLE_NV;
using gl::GL_PATH_MAX_MODELVIEW_STACK_DEPTH_NV;
using gl::GL_PATH_MAX_PROJECTION_STACK_DEPTH_NV;
using gl::GL_PATH_MITER_LIMIT_NV;
using gl::GL_PATH_MODELVIEW_MATRIX_NV;
using gl::GL_PATH_MODELVIEW_NV;
using gl::GL_PATH_MODELVIEW_STACK_DEPTH_NV;
using gl::GL_PATH_OBJECT_BOUNDING_BOX_NV;
using gl::GL_PATH_PROJECTION_MATRIX_NV;
using gl::GL_PATH_PROJECTION_NV;
using gl::GL_PATH_PROJECTION_STACK_DEPTH_NV;
using gl::GL_PATH_STENCIL_DEPTH_OFFSET_FACTOR_NV;
using gl::GL_PATH_STENCIL_DEPTH_OFFSET_UNITS_NV;
using gl::GL_PATH_STENCIL_FUNC_NV;
using gl::GL_PATH_STENCIL_REF_NV;
using gl::GL_PATH_STENCIL_VALUE_MASK_NV;
using gl::GL_PATH_STROKE_BOUNDING_BOX_NV;
using gl::GL_PATH_STROKE_COVER_MODE_NV;
using gl::GL_PATH_STROKE_MASK_NV;
using gl::GL_PATH_STROKE_WIDTH_NV;
using gl::GL_PATH_TERMINAL_DASH_CAP_NV;
using gl::GL_PATH_TERMINAL_END_CAP_NV;
using gl::GL_PATH_TRANSPOSE_MODELVIEW_MATRIX_NV;
using gl::GL_PATH_TRANSPOSE_PROJECTION_MATRIX_NV;
using gl::GL_PER_GPU_STORAGE_NV;
using gl::GL_PER_STAGE_CONSTANTS_NV;
using gl::GL_PERCENTAGE_AMD;
using gl::GL_PERFMON_RESULT_AMD;
using gl::GL_PERFMON_RESULT_AVAILABLE_AMD;
using gl::GL_PERFMON_RESULT_SIZE_AMD;
using gl::GL_PERFORMANCE_MONITOR_AMD;
using gl::GL_PERFQUERY_COUNTER_DATA_BOOL32_INTEL;
using gl::GL_PERFQUERY_COUNTER_DATA_DOUBLE_INTEL;
using gl::GL_PERFQUERY_COUNTER_DATA_FLOAT_INTEL;
using gl::GL_PERFQUERY_COUNTER_DATA_UINT32_INTEL;
using gl::GL_PERFQUERY_COUNTER_DATA_UINT64_INTEL;
using gl::GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL;
using gl::GL_PERFQUERY_COUNTER_DURATION_NORM_INTEL;
using gl::GL_PERFQUERY_COUNTER_DURATION_RAW_INTEL;
using gl::GL_PERFQUERY_COUNTER_EVENT_INTEL;
using gl::GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL;
using gl::GL_PERFQUERY_COUNTER_RAW_INTEL;
using gl::GL_PERFQUERY_COUNTER_THROUGHPUT_INTEL;
using gl::GL_PERFQUERY_COUNTER_TIMESTAMP_INTEL;
using gl::GL_PERFQUERY_DONOT_FLUSH_INTEL;
using gl::GL_PERFQUERY_FLUSH_INTEL;
using gl::GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL;
using gl::GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL;
using gl::GL_PERFQUERY_WAIT_INTEL;
using gl::GL_PERTURB_EXT;
using gl::GL_PHONG_HINT_WIN;
using gl::GL_PHONG_WIN;
using gl::GL_PINLIGHT_NV;
using gl::GL_PIXEL_COUNT_AVAILABLE_NV;
using gl::GL_PIXEL_COUNT_NV;
using gl::GL_PIXEL_COUNTER_BITS_NV;
using gl::GL_PIXEL_CUBIC_WEIGHT_EXT;
using gl::GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS;
using gl::GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS;
using gl::GL_PIXEL_GROUP_COLOR_SGIS;
using gl::GL_PIXEL_MAG_FILTER_EXT;
using gl::GL_PIXEL_MIN_FILTER_EXT;
using gl::GL_PIXEL_PACK_BUFFER_ARB;
using gl::GL_PIXEL_PACK_BUFFER_BINDING_ARB;
using gl::GL_PIXEL_PACK_BUFFER_BINDING_EXT;
using gl::GL_PIXEL_PACK_BUFFER_EXT;
using gl::GL_PIXEL_SUBSAMPLE_2424_SGIX;
using gl::GL_PIXEL_SUBSAMPLE_4242_SGIX;
using gl::GL_PIXEL_SUBSAMPLE_4444_SGIX;
using gl::GL_PIXEL_TEX_GEN_MODE_SGIX;
using gl::GL_PIXEL_TEX_GEN_SGIX;
using gl::GL_PIXEL_TEXTURE_SGIS;
using gl::GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX;
using gl::GL_PIXEL_TILE_CACHE_INCREMENT_SGIX;
using gl::GL_PIXEL_TILE_CACHE_SIZE_SGIX;
using gl::GL_PIXEL_TILE_GRID_DEPTH_SGIX;
using gl::GL_PIXEL_TILE_GRID_HEIGHT_SGIX;
using gl::GL_PIXEL_TILE_GRID_WIDTH_SGIX;
using gl::GL_PIXEL_TILE_HEIGHT_SGIX;
using gl::GL_PIXEL_TILE_WIDTH_SGIX;
using gl::GL_PIXEL_TRANSFORM_2D_EXT;
using gl::GL_PIXEL_TRANSFORM_2D_MATRIX_EXT;
using gl::GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT;
using gl::GL_PIXEL_UNPACK_BUFFER_ARB;
using gl::GL_PIXEL_UNPACK_BUFFER_BINDING_ARB;
using gl::GL_PIXEL_UNPACK_BUFFER_BINDING_EXT;
using gl::GL_PIXEL_UNPACK_BUFFER_EXT;
using gl::GL_PIXELS_PER_SAMPLE_PATTERN_X_AMD;
using gl::GL_PIXELS_PER_SAMPLE_PATTERN_Y_AMD;
using gl::GL_PLUS_CLAMPED_ALPHA_NV;
using gl::GL_PLUS_CLAMPED_NV;
using gl::GL_PLUS_DARKER_NV;
using gl::GL_PLUS_NV;
using gl::GL_PN_TRIANGLES_ATI;
using gl::GL_PN_TRIANGLES_NORMAL_MODE_ATI;
using gl::GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI;
using gl::GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI;
using gl::GL_PN_TRIANGLES_POINT_MODE_ATI;
using gl::GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI;
using gl::GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI;
using gl::GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI;
using gl::GL_POINT_DISTANCE_ATTENUATION_ARB;
using gl::GL_POINT_FADE_THRESHOLD_SIZE_ARB;
using gl::GL_POINT_FADE_THRESHOLD_SIZE_EXT;
using gl::GL_POINT_FADE_THRESHOLD_SIZE_SGIS;
using gl::GL_POINT_SIZE_MAX_ARB;
using gl::GL_POINT_SIZE_MAX_EXT;
using gl::GL_POINT_SIZE_MAX_SGIS;
using gl::GL_POINT_SIZE_MIN_ARB;
using gl::GL_POINT_SIZE_MIN_EXT;
using gl::GL_POINT_SIZE_MIN_SGIS;
using gl::GL_POINT_SPRITE_ARB;
using gl::GL_POINT_SPRITE_NV;
using gl::GL_POINT_SPRITE_R_MODE_NV;
using gl::GL_POLYGON_OFFSET_BIAS_EXT;
using gl::GL_POLYGON_OFFSET_CLAMP;
using gl::GL_POLYGON_OFFSET_CLAMP_EXT;
using gl::GL_POLYGON_OFFSET_COMMAND_NV;
using gl::GL_POLYGON_OFFSET_EXT;
using gl::GL_POLYGON_OFFSET_FACTOR_EXT;
using gl::GL_POST_COLOR_MATRIX_ALPHA_BIAS;
using gl::GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI;
using gl::GL_POST_COLOR_MATRIX_ALPHA_SCALE;
using gl::GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI;
using gl::GL_POST_COLOR_MATRIX_BLUE_BIAS;
using gl::GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI;
using gl::GL_POST_COLOR_MATRIX_BLUE_SCALE;
using gl::GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI;
using gl::GL_POST_COLOR_MATRIX_COLOR_TABLE;
using gl::GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI;
using gl::GL_POST_COLOR_MATRIX_GREEN_BIAS;
using gl::GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI;
using gl::GL_POST_COLOR_MATRIX_GREEN_SCALE;
using gl::GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI;
using gl::GL_POST_COLOR_MATRIX_RED_BIAS;
using gl::GL_POST_COLOR_MATRIX_RED_BIAS_SGI;
using gl::GL_POST_COLOR_MATRIX_RED_SCALE;
using gl::GL_POST_COLOR_MATRIX_RED_SCALE_SGI;
using gl::GL_POST_CONVOLUTION_ALPHA_BIAS;
using gl::GL_POST_CONVOLUTION_ALPHA_BIAS_EXT;
using gl::GL_POST_CONVOLUTION_ALPHA_SCALE;
using gl::GL_POST_CONVOLUTION_ALPHA_SCALE_EXT;
using gl::GL_POST_CONVOLUTION_BLUE_BIAS;
using gl::GL_POST_CONVOLUTION_BLUE_BIAS_EXT;
using gl::GL_POST_CONVOLUTION_BLUE_SCALE;
using gl::GL_POST_CONVOLUTION_BLUE_SCALE_EXT;
using gl::GL_POST_CONVOLUTION_COLOR_TABLE;
using gl::GL_POST_CONVOLUTION_COLOR_TABLE_SGI;
using gl::GL_POST_CONVOLUTION_GREEN_BIAS;
using gl::GL_POST_CONVOLUTION_GREEN_BIAS_EXT;
using gl::GL_POST_CONVOLUTION_GREEN_SCALE;
using gl::GL_POST_CONVOLUTION_GREEN_SCALE_EXT;
using gl::GL_POST_CONVOLUTION_RED_BIAS;
using gl::GL_POST_CONVOLUTION_RED_BIAS_EXT;
using gl::GL_POST_CONVOLUTION_RED_SCALE;
using gl::GL_POST_CONVOLUTION_RED_SCALE_EXT;
using gl::GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP;
using gl::GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX;
using gl::GL_POST_TEXTURE_FILTER_BIAS_SGIX;
using gl::GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX;
using gl::GL_POST_TEXTURE_FILTER_SCALE_SGIX;
using gl::GL_PREFER_DOUBLEBUFFER_HINT_PGI;
using gl::GL_PRESENT_DURATION_NV;
using gl::GL_PRESENT_TIME_NV;
using gl::GL_PRESERVE_ATI;
using gl::GL_PREVIOUS_ARB;
using gl::GL_PREVIOUS_EXT;
using gl::GL_PREVIOUS_TEXTURE_INPUT_NV;
using gl::GL_PRIMARY_COLOR_ARB;
using gl::GL_PRIMARY_COLOR_EXT;
using gl::GL_PRIMARY_COLOR_NV;
using gl::GL_PRIMITIVE_BOUNDING_BOX_ARB;
using gl::GL_PRIMITIVE_ID_NV;
using gl::GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED;
using gl::GL_PRIMITIVE_RESTART_INDEX_NV;
using gl::GL_PRIMITIVE_RESTART_NV;
using gl::GL_PRIMITIVES_GENERATED_EXT;
using gl::GL_PRIMITIVES_GENERATED_NV;
using gl::GL_PRIMITIVES_SUBMITTED;
using gl::GL_PRIMITIVES_SUBMITTED_ARB;
using gl::GL_PROGRAM_ADDRESS_REGISTERS_ARB;
using gl::GL_PROGRAM_ALU_INSTRUCTIONS_ARB;
using gl::GL_PROGRAM_ATTRIB_COMPONENTS_NV;
using gl::GL_PROGRAM_ATTRIBS_ARB;
using gl::GL_PROGRAM_BINARY_FORMAT_MESA;
using gl::GL_PROGRAM_BINDING_ARB;
using gl::GL_PROGRAM_ERROR_POSITION_ARB;
using gl::GL_PROGRAM_ERROR_POSITION_NV;
using gl::GL_PROGRAM_ERROR_STRING_ARB;
using gl::GL_PROGRAM_ERROR_STRING_NV;
using gl::GL_PROGRAM_FORMAT_ARB;
using gl::GL_PROGRAM_FORMAT_ASCII_ARB;
using gl::GL_PROGRAM_INSTRUCTIONS_ARB;
using gl::GL_PROGRAM_KHR;
using gl::GL_PROGRAM_LENGTH_ARB;
using gl::GL_PROGRAM_LENGTH_NV;
using gl::GL_PROGRAM_MATRIX_EXT;
using gl::GL_PROGRAM_MATRIX_STACK_DEPTH_EXT;
using gl::GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB;
using gl::GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB;
using gl::GL_PROGRAM_NATIVE_ATTRIBS_ARB;
using gl::GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB;
using gl::GL_PROGRAM_NATIVE_PARAMETERS_ARB;
using gl::GL_PROGRAM_NATIVE_TEMPORARIES_ARB;
using gl::GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB;
using gl::GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB;
using gl::GL_PROGRAM_OBJECT_ARB;
using gl::GL_PROGRAM_OBJECT_EXT;
using gl::GL_PROGRAM_PARAMETER_NV;
using gl::GL_PROGRAM_PARAMETERS_ARB;
using gl::GL_PROGRAM_PIPELINE_BINDING_EXT;
using gl::GL_PROGRAM_PIPELINE_KHR;
using gl::GL_PROGRAM_PIPELINE_OBJECT_EXT;
using gl::GL_PROGRAM_POINT_SIZE_ARB;
using gl::GL_PROGRAM_POINT_SIZE_EXT;
using gl::GL_PROGRAM_RESIDENT_NV;
using gl::GL_PROGRAM_RESULT_COMPONENTS_NV;
using gl::GL_PROGRAM_SEPARABLE_EXT;
using gl::GL_PROGRAM_STRING_ARB;
using gl::GL_PROGRAM_STRING_NV;
using gl::GL_PROGRAM_TARGET_NV;
using gl::GL_PROGRAM_TEMPORARIES_ARB;
using gl::GL_PROGRAM_TEX_INDIRECTIONS_ARB;
using gl::GL_PROGRAM_TEX_INSTRUCTIONS_ARB;
using gl::GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB;
using gl::GL_PROGRAMMABLE_SAMPLE_LOCATION_ARB;
using gl::GL_PROGRAMMABLE_SAMPLE_LOCATION_NV;
using gl::GL_PROGRAMMABLE_SAMPLE_LOCATION_TABLE_SIZE_ARB;
using gl::GL_PROGRAMMABLE_SAMPLE_LOCATION_TABLE_SIZE_NV;
using gl::GL_PROTECTED_MEMORY_OBJECT_EXT;
using gl::GL_PROVOKING_VERTEX_EXT;
using gl::GL_PROXY_COLOR_TABLE;
using gl::GL_PROXY_COLOR_TABLE_SGI;
using gl::GL_PROXY_HISTOGRAM;
using gl::GL_PROXY_HISTOGRAM_EXT;
using gl::GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE;
using gl::GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI;
using gl::GL_PROXY_POST_CONVOLUTION_COLOR_TABLE;
using gl::GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI;
using gl::GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP;
using gl::GL_PROXY_TEXTURE_1D_ARRAY_EXT;
using gl::GL_PROXY_TEXTURE_1D_EXT;
using gl::GL_PROXY_TEXTURE_1D_STACK_MESAX;
using gl::GL_PROXY_TEXTURE_2D_ARRAY_EXT;
using gl::GL_PROXY_TEXTURE_2D_EXT;
using gl::GL_PROXY_TEXTURE_2D_STACK_MESAX;
using gl::GL_PROXY_TEXTURE_3D_EXT;
using gl::GL_PROXY_TEXTURE_4D_SGIS;
using gl::GL_PROXY_TEXTURE_COLOR_TABLE_SGI;
using gl::GL_PROXY_TEXTURE_CUBE_MAP_ARB;
using gl::GL_PROXY_TEXTURE_CUBE_MAP_ARRAY_ARB;
using gl::GL_PROXY_TEXTURE_CUBE_MAP_EXT;
using gl::GL_PROXY_TEXTURE_RECTANGLE_ARB;
using gl::GL_PROXY_TEXTURE_RECTANGLE_NV;
using gl::GL_PURGEABLE_APPLE;
using gl::GL_PURGED_CONTEXT_RESET_NV;
using gl::GL_QUAD_ALPHA4_SGIS;
using gl::GL_QUAD_ALPHA8_SGIS;
using gl::GL_QUAD_INTENSITY4_SGIS;
using gl::GL_QUAD_INTENSITY8_SGIS;
using gl::GL_QUAD_LUMINANCE4_SGIS;
using gl::GL_QUAD_LUMINANCE8_SGIS;
using gl::GL_QUAD_MESH_SUN;
using gl::GL_QUAD_TEXTURE_SELECT_SGIS;
using gl::GL_QUADRATIC_CURVE_TO_NV;
using gl::GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION_EXT;
using gl::GL_QUERY_BUFFER;
using gl::GL_QUERY_BUFFER_AMD;
using gl::GL_QUERY_BUFFER_BINDING;
using gl::GL_QUERY_BUFFER_BINDING_AMD;
using gl::GL_QUERY_BY_REGION_NO_WAIT_INVERTED;
using gl::GL_QUERY_BY_REGION_NO_WAIT_NV;
using gl::GL_QUERY_BY_REGION_WAIT_INVERTED;
using gl::GL_QUERY_BY_REGION_WAIT_NV;
using gl::GL_QUERY_COUNTER_BITS_ARB;
using gl::GL_QUERY_KHR;
using gl::GL_QUERY_NO_WAIT_INVERTED;
using gl::GL_QUERY_NO_WAIT_NV;
using gl::GL_QUERY_OBJECT_AMD;
using gl::GL_QUERY_OBJECT_EXT;
using gl::GL_QUERY_RESOURCE_BUFFEROBJECT_NV;
using gl::GL_QUERY_RESOURCE_MEMTYPE_VIDMEM_NV;
using gl::GL_QUERY_RESOURCE_RENDERBUFFER_NV;
using gl::GL_QUERY_RESOURCE_SYS_RESERVED_NV;
using gl::GL_QUERY_RESOURCE_TEXTURE_NV;
using gl::GL_QUERY_RESOURCE_TYPE_VIDMEM_ALLOC_NV;
using gl::GL_QUERY_RESULT_ARB;
using gl::GL_QUERY_RESULT_AVAILABLE_ARB;
using gl::GL_QUERY_RESULT_NO_WAIT;
using gl::GL_QUERY_RESULT_NO_WAIT_AMD;
using gl::GL_QUERY_TARGET;
using gl::GL_QUERY_WAIT_INVERTED;
using gl::GL_QUERY_WAIT_NV;
using gl::GL_R11F_G11F_B10F_EXT;
using gl::GL_R16F_EXT;
using gl::GL_R1UI_C3F_V3F_SUN;
using gl::GL_R1UI_C4F_N3F_V3F_SUN;
using gl::GL_R1UI_C4UB_V3F_SUN;
using gl::GL_R1UI_N3F_V3F_SUN;
using gl::GL_R1UI_T2F_C4F_N3F_V3F_SUN;
using gl::GL_R1UI_T2F_N3F_V3F_SUN;
using gl::GL_R1UI_T2F_V3F_SUN;
using gl::GL_R1UI_V3F_SUN;
using gl::GL_R32F_EXT;
using gl::GL_R8_EXT;
using gl::GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT;
using gl::GL_RASTER_MULTISAMPLE_EXT;
using gl::GL_RASTER_POSITION_UNCLIPPED_IBM;
using gl::GL_RASTER_SAMPLES_EXT;
using gl::GL_RASTERIZER_DISCARD_EXT;
using gl::GL_RASTERIZER_DISCARD_NV;
using gl::GL_READ_FRAMEBUFFER_BINDING_EXT;
using gl::GL_READ_FRAMEBUFFER_EXT;
using gl::GL_READ_ONLY_ARB;
using gl::GL_READ_PIXEL_DATA_RANGE_LENGTH_NV;
using gl::GL_READ_PIXEL_DATA_RANGE_NV;
using gl::GL_READ_PIXEL_DATA_RANGE_POINTER_NV;
using gl::GL_READ_WRITE_ARB;
using gl::GL_RECLAIM_MEMORY_HINT_PGI;
using gl::GL_RECT_NV;
using gl::GL_RED_INTEGER_EXT;
using gl::GL_RED_MAX_CLAMP_INGR;
using gl::GL_RED_MIN_CLAMP_INGR;
using gl::GL_RED_NV;
using gl::GL_RED_SNORM;
using gl::GL_REDUCE;
using gl::GL_REDUCE_EXT;
using gl::GL_REFERENCE_PLANE_EQUATION_SGIX;
using gl::GL_REFERENCE_PLANE_SGIX;
using gl::GL_REFERENCED_BY_MESH_SHADER_NV;
using gl::GL_REFERENCED_BY_TASK_SHADER_NV;
using gl::GL_REFLECTION_MAP_ARB;
using gl::GL_REFLECTION_MAP_EXT;
using gl::GL_REFLECTION_MAP_NV;
using gl::GL_REG_0_ATI;
using gl::GL_REG_10_ATI;
using gl::GL_REG_11_ATI;
using gl::GL_REG_12_ATI;
using gl::GL_REG_13_ATI;
using gl::GL_REG_14_ATI;
using gl::GL_REG_15_ATI;
using gl::GL_REG_16_ATI;
using gl::GL_REG_17_ATI;
using gl::GL_REG_18_ATI;
using gl::GL_REG_19_ATI;
using gl::GL_REG_1_ATI;
using gl::GL_REG_20_ATI;
using gl::GL_REG_21_ATI;
using gl::GL_REG_22_ATI;
using gl::GL_REG_23_ATI;
using gl::GL_REG_24_ATI;
using gl::GL_REG_25_ATI;
using gl::GL_REG_26_ATI;
using gl::GL_REG_27_ATI;
using gl::GL_REG_28_ATI;
using gl::GL_REG_29_ATI;
using gl::GL_REG_2_ATI;
using gl::GL_REG_30_ATI;
using gl::GL_REG_31_ATI;
using gl::GL_REG_3_ATI;
using gl::GL_REG_4_ATI;
using gl::GL_REG_5_ATI;
using gl::GL_REG_6_ATI;
using gl::GL_REG_7_ATI;
using gl::GL_REG_8_ATI;
using gl::GL_REG_9_ATI;
using gl::GL_REGISTER_COMBINERS_NV;
using gl::GL_RELATIVE_ARC_TO_NV;
using gl::GL_RELATIVE_CONIC_CURVE_TO_NV;
using gl::GL_RELATIVE_CUBIC_CURVE_TO_NV;
using gl::GL_RELATIVE_HORIZONTAL_LINE_TO_NV;
using gl::GL_RELATIVE_LARGE_CCW_ARC_TO_NV;
using gl::GL_RELATIVE_LARGE_CW_ARC_TO_NV;
using gl::GL_RELATIVE_LINE_TO_NV;
using gl::GL_RELATIVE_MOVE_TO_NV;
using gl::GL_RELATIVE_QUADRATIC_CURVE_TO_NV;
using gl::GL_RELATIVE_RECT_NV;
using gl::GL_RELATIVE_ROUNDED_RECT2_NV;
using gl::GL_RELATIVE_ROUNDED_RECT4_NV;
using gl::GL_RELATIVE_ROUNDED_RECT8_NV;
using gl::GL_RELATIVE_ROUNDED_RECT_NV;
using gl::GL_RELATIVE_SMALL_CCW_ARC_TO_NV;
using gl::GL_RELATIVE_SMALL_CW_ARC_TO_NV;
using gl::GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV;
using gl::GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV;
using gl::GL_RELATIVE_VERTICAL_LINE_TO_NV;
using gl::GL_RELEASED_APPLE;
using gl::GL_RENDER_GPU_MASK_NV;
using gl::GL_RENDERBUFFER_ALPHA_SIZE_EXT;
using gl::GL_RENDERBUFFER_BINDING_EXT;
using gl::GL_RENDERBUFFER_BLUE_SIZE_EXT;
using gl::GL_RENDERBUFFER_COLOR_SAMPLES_NV;
using gl::GL_RENDERBUFFER_COVERAGE_SAMPLES_NV;
using gl::GL_RENDERBUFFER_DEPTH_SIZE_EXT;
using gl::GL_RENDERBUFFER_EXT;
using gl::GL_RENDERBUFFER_FREE_MEMORY_ATI;
using gl::GL_RENDERBUFFER_GREEN_SIZE_EXT;
using gl::GL_RENDERBUFFER_HEIGHT_EXT;
using gl::GL_RENDERBUFFER_INTERNAL_FORMAT_EXT;
using gl::GL_RENDERBUFFER_RED_SIZE_EXT;
using gl::GL_RENDERBUFFER_SAMPLES_EXT;
using gl::GL_RENDERBUFFER_STENCIL_SIZE_EXT;
using gl::GL_RENDERBUFFER_STORAGE_SAMPLES_AMD;
using gl::GL_RENDERBUFFER_WIDTH_EXT;
using gl::GL_REPLACE_EXT;
using gl::GL_REPLACE_MIDDLE_SUN;
using gl::GL_REPLACE_OLDEST_SUN;
using gl::GL_REPLACE_VALUE_AMD;
using gl::GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN;
using gl::GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN;
using gl::GL_REPLACEMENT_CODE_ARRAY_SUN;
using gl::GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN;
using gl::GL_REPLACEMENT_CODE_SUN;
using gl::GL_REPLICATE_BORDER;
using gl::GL_REPLICATE_BORDER_HP;
using gl::GL_REPRESENTATIVE_FRAGMENT_TEST_NV;
using gl::GL_RESAMPLE_AVERAGE_OML;
using gl::GL_RESAMPLE_DECIMATE_OML;
using gl::GL_RESAMPLE_DECIMATE_SGIX;
using gl::GL_RESAMPLE_REPLICATE_OML;
using gl::GL_RESAMPLE_REPLICATE_SGIX;
using gl::GL_RESAMPLE_ZERO_FILL_OML;
using gl::GL_RESAMPLE_ZERO_FILL_SGIX;
using gl::GL_RESCALE_NORMAL_EXT;
using gl::GL_RESET_NOTIFICATION_STRATEGY;
using gl::GL_RESET_NOTIFICATION_STRATEGY_ARB;
using gl::GL_RESET_NOTIFICATION_STRATEGY_KHR;
using gl::GL_RESTART_PATH_NV;
using gl::GL_RESTART_SUN;
using gl::GL_RETAINED_APPLE;
using gl::GL_RG16F_EXT;
using gl::GL_RG32F_EXT;
using gl::GL_RG8_EXT;
using gl::GL_RG_SNORM;
using gl::GL_RGB10_A2_EXT;
using gl::GL_RGB10_EXT;
using gl::GL_RGB12_EXT;
using gl::GL_RGB16_EXT;
using gl::GL_RGB16F_ARB;
using gl::GL_RGB16F_EXT;
using gl::GL_RGB16I_EXT;
using gl::GL_RGB16UI_EXT;
using gl::GL_RGB2_EXT;
using gl::GL_RGB32F_ARB;
using gl::GL_RGB32F_EXT;
using gl::GL_RGB32I_EXT;
using gl::GL_RGB32UI_EXT;
using gl::GL_RGB4_EXT;
using gl::GL_RGB4_S3TC;
using gl::GL_RGB5_A1_EXT;
using gl::GL_RGB5_EXT;
using gl::GL_RGB8_EXT;
using gl::GL_RGB8I_EXT;
using gl::GL_RGB8UI_EXT;
using gl::GL_RGB9_E5_EXT;
using gl::GL_RGB_422_APPLE;
using gl::GL_RGB_FLOAT16_APPLE;
using gl::GL_RGB_FLOAT16_ATI;
using gl::GL_RGB_FLOAT32_APPLE;
using gl::GL_RGB_FLOAT32_ATI;
using gl::GL_RGB_INTEGER_EXT;
using gl::GL_RGB_RAW_422_APPLE;
using gl::GL_RGB_S3TC;
using gl::GL_RGB_SCALE_ARB;
using gl::GL_RGB_SCALE_EXT;
using gl::GL_RGB_SNORM;
using gl::GL_RGBA12_EXT;
using gl::GL_RGBA16_EXT;
using gl::GL_RGBA16F_ARB;
using gl::GL_RGBA16F_EXT;
using gl::GL_RGBA16I_EXT;
using gl::GL_RGBA16UI_EXT;
using gl::GL_RGBA2_EXT;
using gl::GL_RGBA32F_ARB;
using gl::GL_RGBA32F_EXT;
using gl::GL_RGBA32I_EXT;
using gl::GL_RGBA32UI_EXT;
using gl::GL_RGBA4_DXT5_S3TC;
using gl::GL_RGBA4_EXT;
using gl::GL_RGBA4_S3TC;
using gl::GL_RGBA8_EXT;
using gl::GL_RGBA8I_EXT;
using gl::GL_RGBA8UI_EXT;
using gl::GL_RGBA_DXT5_S3TC;
using gl::GL_RGBA_FLOAT16_APPLE;
using gl::GL_RGBA_FLOAT16_ATI;
using gl::GL_RGBA_FLOAT32_APPLE;
using gl::GL_RGBA_FLOAT32_ATI;
using gl::GL_RGBA_FLOAT_MODE_ARB;
using gl::GL_RGBA_FLOAT_MODE_ATI;
using gl::GL_RGBA_INTEGER_EXT;
using gl::GL_RGBA_INTEGER_MODE_EXT;
using gl::GL_RGBA_S3TC;
using gl::GL_RGBA_SIGNED_COMPONENTS_EXT;
using gl::GL_RGBA_SNORM;
using gl::GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV;
using gl::GL_ROUND_NV;
using gl::GL_ROUNDED_RECT2_NV;
using gl::GL_ROUNDED_RECT4_NV;
using gl::GL_ROUNDED_RECT8_NV;
using gl::GL_ROUNDED_RECT_NV;
using gl::GL_SAMPLE_ALPHA_TO_COVERAGE_ARB;
using gl::GL_SAMPLE_ALPHA_TO_MASK_EXT;
using gl::GL_SAMPLE_ALPHA_TO_MASK_SGIS;
using gl::GL_SAMPLE_ALPHA_TO_ONE_ARB;
using gl::GL_SAMPLE_ALPHA_TO_ONE_EXT;
using gl::GL_SAMPLE_ALPHA_TO_ONE_SGIS;
using gl::GL_SAMPLE_BUFFERS_3DFX;
using gl::GL_SAMPLE_BUFFERS_ARB;
using gl::GL_SAMPLE_BUFFERS_EXT;
using gl::GL_SAMPLE_BUFFERS_SGIS;
using gl::GL_SAMPLE_COVERAGE_ARB;
using gl::GL_SAMPLE_COVERAGE_INVERT_ARB;
using gl::GL_SAMPLE_COVERAGE_VALUE_ARB;
using gl::GL_SAMPLE_LOCATION_ARB;
using gl::GL_SAMPLE_LOCATION_NV;
using gl::GL_SAMPLE_LOCATION_PIXEL_GRID_HEIGHT_ARB;
using gl::GL_SAMPLE_LOCATION_PIXEL_GRID_HEIGHT_NV;
using gl::GL_SAMPLE_LOCATION_PIXEL_GRID_WIDTH_ARB;
using gl::GL_SAMPLE_LOCATION_PIXEL_GRID_WIDTH_NV;
using gl::GL_SAMPLE_LOCATION_SUBPIXEL_BITS_ARB;
using gl::GL_SAMPLE_LOCATION_SUBPIXEL_BITS_NV;
using gl::GL_SAMPLE_MASK_EXT;
using gl::GL_SAMPLE_MASK_INVERT_EXT;
using gl::GL_SAMPLE_MASK_INVERT_SGIS;
using gl::GL_SAMPLE_MASK_NV;
using gl::GL_SAMPLE_MASK_SGIS;
using gl::GL_SAMPLE_MASK_VALUE_EXT;
using gl::GL_SAMPLE_MASK_VALUE_NV;
using gl::GL_SAMPLE_MASK_VALUE_SGIS;
using gl::GL_SAMPLE_PATTERN_EXT;
using gl::GL_SAMPLE_PATTERN_SGIS;
using gl::GL_SAMPLE_POSITION_NV;
using gl::GL_SAMPLE_SHADING_ARB;
using gl::GL_SAMPLER_1D_ARB;
using gl::GL_SAMPLER_1D_ARRAY_EXT;
using gl::GL_SAMPLER_1D_ARRAY_SHADOW_EXT;
using gl::GL_SAMPLER_1D_SHADOW_ARB;
using gl::GL_SAMPLER_2D_ARB;
using gl::GL_SAMPLER_2D_ARRAY_EXT;
using gl::GL_SAMPLER_2D_ARRAY_SHADOW_EXT;
using gl::GL_SAMPLER_2D_RECT_ARB;
using gl::GL_SAMPLER_2D_RECT_SHADOW_ARB;
using gl::GL_SAMPLER_2D_SHADOW_ARB;
using gl::GL_SAMPLER_3D_ARB;
using gl::GL_SAMPLER_BUFFER_AMD;
using gl::GL_SAMPLER_BUFFER_EXT;
using gl::GL_SAMPLER_CUBE_ARB;
using gl::GL_SAMPLER_CUBE_MAP_ARRAY_ARB;
using gl::GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_ARB;
using gl::GL_SAMPLER_CUBE_SHADOW_EXT;
using gl::GL_SAMPLER_KHR;
using gl::GL_SAMPLER_OBJECT_AMD;
using gl::GL_SAMPLER_RENDERBUFFER_NV;
using gl::GL_SAMPLES_3DFX;
using gl::GL_SAMPLES_ARB;
using gl::GL_SAMPLES_EXT;
using gl::GL_SAMPLES_PASSED_ARB;
using gl::GL_SAMPLES_SGIS;
using gl::GL_SCALAR_EXT;
using gl::GL_SCALE_BY_FOUR_NV;
using gl::GL_SCALE_BY_ONE_HALF_NV;
using gl::GL_SCALE_BY_TWO_NV;
using gl::GL_SCALEBIAS_HINT_SGIX;
using gl::GL_SCALED_RESOLVE_FASTEST_EXT;
using gl::GL_SCALED_RESOLVE_NICEST_EXT;
using gl::GL_SCISSOR_BOX_EXCLUSIVE_NV;
using gl::GL_SCISSOR_COMMAND_NV;
using gl::GL_SCISSOR_TEST_EXCLUSIVE_NV;
using gl::GL_SCREEN_COORDINATES_REND;
using gl::GL_SCREEN_KHR;
using gl::GL_SCREEN_NV;
using gl::GL_SECONDARY_COLOR_ARRAY_ADDRESS_NV;
using gl::GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_SECONDARY_COLOR_ARRAY_EXT;
using gl::GL_SECONDARY_COLOR_ARRAY_LENGTH_NV;
using gl::GL_SECONDARY_COLOR_ARRAY_LIST_IBM;
using gl::GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM;
using gl::GL_SECONDARY_COLOR_ARRAY_POINTER_EXT;
using gl::GL_SECONDARY_COLOR_ARRAY_SIZE_EXT;
using gl::GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT;
using gl::GL_SECONDARY_COLOR_ARRAY_TYPE_EXT;
using gl::GL_SECONDARY_COLOR_NV;
using gl::GL_SECONDARY_INTERPOLATOR_ATI;
using gl::GL_SEMAPHORE_TYPE_BINARY_NV;
using gl::GL_SEMAPHORE_TYPE_NV;
using gl::GL_SEMAPHORE_TYPE_TIMELINE_NV;
using gl::GL_SEPARABLE_2D;
using gl::GL_SEPARABLE_2D_EXT;
using gl::GL_SEPARATE_ATTRIBS_EXT;
using gl::GL_SEPARATE_ATTRIBS_NV;
using gl::GL_SEPARATE_SPECULAR_COLOR_EXT;
using gl::GL_SET_AMD;
using gl::GL_SHADER_BINARY_FORMAT_SPIR_V;
using gl::GL_SHADER_BINARY_FORMAT_SPIR_V_ARB;
using gl::GL_SHADER_CONSISTENT_NV;
using gl::GL_SHADER_INCLUDE_ARB;
using gl::GL_SHADER_KHR;
using gl::GL_SHADER_OBJECT_ARB;
using gl::GL_SHADER_OBJECT_EXT;
using gl::GL_SHADER_OPERATION_NV;
using gl::GL_SHADING_LANGUAGE_VERSION_ARB;
using gl::GL_SHADING_RATE_16_INVOCATIONS_PER_PIXEL_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_1X2_PIXELS_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_2X1_PIXELS_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_2X2_PIXELS_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_2X4_PIXELS_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_4X2_PIXELS_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_4X4_PIXELS_NV;
using gl::GL_SHADING_RATE_1_INVOCATION_PER_PIXEL_NV;
using gl::GL_SHADING_RATE_2_INVOCATIONS_PER_PIXEL_NV;
using gl::GL_SHADING_RATE_4_INVOCATIONS_PER_PIXEL_NV;
using gl::GL_SHADING_RATE_8_INVOCATIONS_PER_PIXEL_NV;
using gl::GL_SHADING_RATE_IMAGE_BINDING_NV;
using gl::GL_SHADING_RATE_IMAGE_NV;
using gl::GL_SHADING_RATE_IMAGE_PALETTE_COUNT_NV;
using gl::GL_SHADING_RATE_IMAGE_PALETTE_SIZE_NV;
using gl::GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV;
using gl::GL_SHADING_RATE_IMAGE_TEXEL_HEIGHT_NV;
using gl::GL_SHADING_RATE_IMAGE_TEXEL_WIDTH_NV;
using gl::GL_SHADING_RATE_NO_INVOCATIONS_NV;
using gl::GL_SHADING_RATE_SAMPLE_ORDER_DEFAULT_NV;
using gl::GL_SHADING_RATE_SAMPLE_ORDER_PIXEL_MAJOR_NV;
using gl::GL_SHADING_RATE_SAMPLE_ORDER_SAMPLE_MAJOR_NV;
using gl::GL_SHADOW_AMBIENT_SGIX;
using gl::GL_SHADOW_ATTENUATION_EXT;
using gl::GL_SHARED_EDGE_NV;
using gl::GL_SHARED_TEXTURE_PALETTE_EXT;
using gl::GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS;
using gl::GL_SIGNED_ALPHA8_NV;
using gl::GL_SIGNED_ALPHA_NV;
using gl::GL_SIGNED_HILO16_NV;
using gl::GL_SIGNED_HILO8_NV;
using gl::GL_SIGNED_HILO_NV;
using gl::GL_SIGNED_IDENTITY_NV;
using gl::GL_SIGNED_INTENSITY8_NV;
using gl::GL_SIGNED_INTENSITY_NV;
using gl::GL_SIGNED_LUMINANCE8_ALPHA8_NV;
using gl::GL_SIGNED_LUMINANCE8_NV;
using gl::GL_SIGNED_LUMINANCE_ALPHA_NV;
using gl::GL_SIGNED_LUMINANCE_NV;
using gl::GL_SIGNED_NEGATE_NV;
using gl::GL_SIGNED_RGB8_NV;
using gl::GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV;
using gl::GL_SIGNED_RGB_NV;
using gl::GL_SIGNED_RGB_UNSIGNED_ALPHA_NV;
using gl::GL_SIGNED_RGBA8_NV;
using gl::GL_SIGNED_RGBA_NV;
using gl::GL_SINGLE_COLOR_EXT;
using gl::GL_SKIP_COMPONENTS1_NV;
using gl::GL_SKIP_COMPONENTS2_NV;
using gl::GL_SKIP_COMPONENTS3_NV;
using gl::GL_SKIP_COMPONENTS4_NV;
using gl::GL_SKIP_DECODE_EXT;
using gl::GL_SKIP_MISSING_GLYPH_NV;
using gl::GL_SLICE_ACCUM_SUN;
using gl::GL_SLUMINANCE8_ALPHA8_EXT;
using gl::GL_SLUMINANCE8_EXT;
using gl::GL_SLUMINANCE_ALPHA_EXT;
using gl::GL_SLUMINANCE_EXT;
using gl::GL_SM_COUNT_NV;
using gl::GL_SMALL_CCW_ARC_TO_NV;
using gl::GL_SMALL_CW_ARC_TO_NV;
using gl::GL_SMOOTH_CUBIC_CURVE_TO_NV;
using gl::GL_SMOOTH_QUADRATIC_CURVE_TO_NV;
using gl::GL_SOFTLIGHT_KHR;
using gl::GL_SOFTLIGHT_NV;
using gl::GL_SOURCE0_ALPHA_ARB;
using gl::GL_SOURCE0_ALPHA_EXT;
using gl::GL_SOURCE0_RGB_ARB;
using gl::GL_SOURCE0_RGB_EXT;
using gl::GL_SOURCE1_ALPHA_ARB;
using gl::GL_SOURCE1_ALPHA_EXT;
using gl::GL_SOURCE1_RGB_ARB;
using gl::GL_SOURCE1_RGB_EXT;
using gl::GL_SOURCE2_ALPHA_ARB;
using gl::GL_SOURCE2_ALPHA_EXT;
using gl::GL_SOURCE2_RGB_ARB;
using gl::GL_SOURCE2_RGB_EXT;
using gl::GL_SOURCE3_ALPHA_NV;
using gl::GL_SOURCE3_RGB_NV;
using gl::GL_SPARE0_NV;
using gl::GL_SPARE0_PLUS_SECONDARY_COLOR_NV;
using gl::GL_SPARE1_NV;
using gl::GL_SPARSE_BUFFER_PAGE_SIZE_ARB;
using gl::GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_ARB;
using gl::GL_SPIR_V_BINARY;
using gl::GL_SPIR_V_BINARY_ARB;
using gl::GL_SPIR_V_EXTENSIONS;
using gl::GL_SPRITE_AXIAL_SGIX;
using gl::GL_SPRITE_AXIS_SGIX;
using gl::GL_SPRITE_EYE_ALIGNED_SGIX;
using gl::GL_SPRITE_MODE_SGIX;
using gl::GL_SPRITE_OBJECT_ALIGNED_SGIX;
using gl::GL_SPRITE_SGIX;
using gl::GL_SPRITE_TRANSLATION_SGIX;
using gl::GL_SQUARE_NV;
using gl::GL_SR8_EXT;
using gl::GL_SRC_ATOP_NV;
using gl::GL_SRC_IN_NV;
using gl::GL_SRC_NV;
using gl::GL_SRC_OUT_NV;
using gl::GL_SRC_OVER_NV;
using gl::GL_SRG8_EXT;
using gl::GL_SRGB8_ALPHA8_EXT;
using gl::GL_SRGB8_EXT;
using gl::GL_SRGB_ALPHA_EXT;
using gl::GL_SRGB_DECODE_ARB;
using gl::GL_SRGB_EXT;
using gl::GL_STACK_OVERFLOW_KHR;
using gl::GL_STACK_UNDERFLOW_KHR;
using gl::GL_STANDARD_FONT_FORMAT_NV;
using gl::GL_STANDARD_FONT_NAME_NV;
using gl::GL_STATIC_ATI;
using gl::GL_STATIC_COPY_ARB;
using gl::GL_STATIC_DRAW_ARB;
using gl::GL_STATIC_READ_ARB;
using gl::GL_STATIC_VERTEX_ARRAY_IBM;
using gl::GL_STENCIL_ATTACHMENT_EXT;
using gl::GL_STENCIL_BACK_FAIL_ATI;
using gl::GL_STENCIL_BACK_FUNC_ATI;
using gl::GL_STENCIL_BACK_OP_VALUE_AMD;
using gl::GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI;
using gl::GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI;
using gl::GL_STENCIL_CLEAR_TAG_VALUE_EXT;
using gl::GL_STENCIL_INDEX16_EXT;
using gl::GL_STENCIL_INDEX1_EXT;
using gl::GL_STENCIL_INDEX4_EXT;
using gl::GL_STENCIL_INDEX8_EXT;
using gl::GL_STENCIL_OP_VALUE_AMD;
using gl::GL_STENCIL_REF_COMMAND_NV;
using gl::GL_STENCIL_SAMPLES_NV;
using gl::GL_STENCIL_TAG_BITS_EXT;
using gl::GL_STENCIL_TEST_TWO_SIDE_EXT;
using gl::GL_STORAGE_CACHED_APPLE;
using gl::GL_STORAGE_CLIENT_APPLE;
using gl::GL_STORAGE_PRIVATE_APPLE;
using gl::GL_STORAGE_SHARED_APPLE;
using gl::GL_STREAM_COPY_ARB;
using gl::GL_STREAM_DRAW_ARB;
using gl::GL_STREAM_RASTERIZATION_AMD;
using gl::GL_STREAM_READ_ARB;
using gl::GL_STRICT_DEPTHFUNC_HINT_PGI;
using gl::GL_STRICT_LIGHTING_HINT_PGI;
using gl::GL_STRICT_SCISSOR_HINT_PGI;
using gl::GL_SUB_ATI;
using gl::GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_BASIC_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_PARTITIONED_BIT_NV;
using gl::GL_SUBGROUP_FEATURE_QUAD_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR;
using gl::GL_SUBGROUP_FEATURE_VOTE_BIT_KHR;
using gl::GL_SUBGROUP_QUAD_ALL_STAGES_KHR;
using gl::GL_SUBGROUP_SIZE_KHR;
using gl::GL_SUBGROUP_SUPPORTED_FEATURES_KHR;
using gl::GL_SUBGROUP_SUPPORTED_STAGES_KHR;
using gl::GL_SUBPIXEL_PRECISION_BIAS_X_BITS_NV;
using gl::GL_SUBPIXEL_PRECISION_BIAS_Y_BITS_NV;
using gl::GL_SUBSAMPLE_DISTANCE_AMD;
using gl::GL_SUBTRACT_ARB;
using gl::GL_SUCCESS_NV;
using gl::GL_SUPERSAMPLE_SCALE_X_NV;
using gl::GL_SUPERSAMPLE_SCALE_Y_NV;
using gl::GL_SUPPORTED_MULTISAMPLE_MODES_AMD;
using gl::GL_SURFACE_MAPPED_NV;
using gl::GL_SURFACE_REGISTERED_NV;
using gl::GL_SURFACE_STATE_NV;
using gl::GL_SWIZZLE_STQ_ATI;
using gl::GL_SWIZZLE_STQ_DQ_ATI;
using gl::GL_SWIZZLE_STR_ATI;
using gl::GL_SWIZZLE_STR_DR_ATI;
using gl::GL_SWIZZLE_STRQ_ATI;
using gl::GL_SWIZZLE_STRQ_DQ_ATI;
using gl::GL_SYNC_CL_EVENT_ARB;
using gl::GL_SYNC_CL_EVENT_COMPLETE_ARB;
using gl::GL_SYNC_X11_FENCE_EXT;
using gl::GL_SYSTEM_FONT_NAME_NV;
using gl::GL_T2F_IUI_N3F_V2F_EXT;
using gl::GL_T2F_IUI_N3F_V3F_EXT;
using gl::GL_T2F_IUI_V2F_EXT;
using gl::GL_T2F_IUI_V3F_EXT;
using gl::GL_TABLE_TOO_LARGE;
using gl::GL_TABLE_TOO_LARGE_EXT;
using gl::GL_TANGENT_ARRAY_EXT;
using gl::GL_TANGENT_ARRAY_POINTER_EXT;
using gl::GL_TANGENT_ARRAY_STRIDE_EXT;
using gl::GL_TANGENT_ARRAY_TYPE_EXT;
using gl::GL_TASK_SHADER_NV;
using gl::GL_TASK_SUBROUTINE_NV;
using gl::GL_TASK_SUBROUTINE_UNIFORM_NV;
using gl::GL_TASK_WORK_GROUP_SIZE_NV;
using gl::GL_TERMINATE_SEQUENCE_COMMAND_NV;
using gl::GL_TESS_CONTROL_PROGRAM_NV;
using gl::GL_TESS_CONTROL_PROGRAM_PARAMETER_BUFFER_NV;
using gl::GL_TESS_CONTROL_SHADER_PATCHES;
using gl::GL_TESS_CONTROL_SHADER_PATCHES_ARB;
using gl::GL_TESS_EVALUATION_PROGRAM_NV;
using gl::GL_TESS_EVALUATION_PROGRAM_PARAMETER_BUFFER_NV;
using gl::GL_TESS_EVALUATION_SHADER_INVOCATIONS;
using gl::GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB;
using gl::GL_TESSELLATION_FACTOR_AMD;
using gl::GL_TESSELLATION_MODE_AMD;
using gl::GL_TEXT_FRAGMENT_SHADER_ATI;
using gl::GL_TEXTURE0_ARB;
using gl::GL_TEXTURE10_ARB;
using gl::GL_TEXTURE11_ARB;
using gl::GL_TEXTURE12_ARB;
using gl::GL_TEXTURE13_ARB;
using gl::GL_TEXTURE14_ARB;
using gl::GL_TEXTURE15_ARB;
using gl::GL_TEXTURE16_ARB;
using gl::GL_TEXTURE17_ARB;
using gl::GL_TEXTURE18_ARB;
using gl::GL_TEXTURE19_ARB;
using gl::GL_TEXTURE1_ARB;
using gl::GL_TEXTURE20_ARB;
using gl::GL_TEXTURE21_ARB;
using gl::GL_TEXTURE22_ARB;
using gl::GL_TEXTURE23_ARB;
using gl::GL_TEXTURE24_ARB;
using gl::GL_TEXTURE25_ARB;
using gl::GL_TEXTURE26_ARB;
using gl::GL_TEXTURE27_ARB;
using gl::GL_TEXTURE28_ARB;
using gl::GL_TEXTURE29_ARB;
using gl::GL_TEXTURE2_ARB;
using gl::GL_TEXTURE30_ARB;
using gl::GL_TEXTURE31_ARB;
using gl::GL_TEXTURE3_ARB;
using gl::GL_TEXTURE4_ARB;
using gl::GL_TEXTURE5_ARB;
using gl::GL_TEXTURE6_ARB;
using gl::GL_TEXTURE7_ARB;
using gl::GL_TEXTURE8_ARB;
using gl::GL_TEXTURE9_ARB;
using gl::GL_TEXTURE_1D_ARRAY_EXT;
using gl::GL_TEXTURE_1D_BINDING_EXT;
using gl::GL_TEXTURE_1D_STACK_BINDING_MESAX;
using gl::GL_TEXTURE_1D_STACK_MESAX;
using gl::GL_TEXTURE_2D_ARRAY_EXT;
using gl::GL_TEXTURE_2D_BINDING_EXT;
using gl::GL_TEXTURE_2D_STACK_BINDING_MESAX;
using gl::GL_TEXTURE_2D_STACK_MESAX;
using gl::GL_TEXTURE_3D_BINDING_EXT;
using gl::GL_TEXTURE_3D_EXT;
using gl::GL_TEXTURE_4D_BINDING_SGIS;
using gl::GL_TEXTURE_4D_SGIS;
using gl::GL_TEXTURE_4DSIZE_SGIS;
using gl::GL_TEXTURE_ALPHA_SIZE_EXT;
using gl::GL_TEXTURE_ALPHA_TYPE_ARB;
using gl::GL_TEXTURE_APPLICATION_MODE_EXT;
using gl::GL_TEXTURE_BASE_LEVEL_SGIS;
using gl::GL_TEXTURE_BINDING_1D_ARRAY_EXT;
using gl::GL_TEXTURE_BINDING_2D_ARRAY_EXT;
using gl::GL_TEXTURE_BINDING_BUFFER_ARB;
using gl::GL_TEXTURE_BINDING_BUFFER_EXT;
using gl::GL_TEXTURE_BINDING_CUBE_MAP_ARB;
using gl::GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_ARB;
using gl::GL_TEXTURE_BINDING_CUBE_MAP_EXT;
using gl::GL_TEXTURE_BINDING_RECTANGLE_ARB;
using gl::GL_TEXTURE_BINDING_RECTANGLE_NV;
using gl::GL_TEXTURE_BINDING_RENDERBUFFER_NV;
using gl::GL_TEXTURE_BLUE_SIZE_EXT;
using gl::GL_TEXTURE_BLUE_TYPE_ARB;
using gl::GL_TEXTURE_BORDER_VALUES_NV;
using gl::GL_TEXTURE_BUFFER_ARB;
using gl::GL_TEXTURE_BUFFER_BINDING;
using gl::GL_TEXTURE_BUFFER_DATA_STORE_BINDING_ARB;
using gl::GL_TEXTURE_BUFFER_DATA_STORE_BINDING_EXT;
using gl::GL_TEXTURE_BUFFER_EXT;
using gl::GL_TEXTURE_BUFFER_FORMAT_ARB;
using gl::GL_TEXTURE_BUFFER_FORMAT_EXT;
using gl::GL_TEXTURE_CLIPMAP_CENTER_SGIX;
using gl::GL_TEXTURE_CLIPMAP_DEPTH_SGIX;
using gl::GL_TEXTURE_CLIPMAP_FRAME_SGIX;
using gl::GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX;
using gl::GL_TEXTURE_CLIPMAP_OFFSET_SGIX;
using gl::GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX;
using gl::GL_TEXTURE_COLOR_SAMPLES_NV;
using gl::GL_TEXTURE_COLOR_TABLE_SGI;
using gl::GL_TEXTURE_COLOR_WRITEMASK_SGIS;
using gl::GL_TEXTURE_COMPARE_FAIL_VALUE_ARB;
using gl::GL_TEXTURE_COMPARE_FUNC_ARB;
using gl::GL_TEXTURE_COMPARE_MODE_ARB;
using gl::GL_TEXTURE_COMPARE_OPERATOR_SGIX;
using gl::GL_TEXTURE_COMPARE_SGIX;
using gl::GL_TEXTURE_COMPRESSED_ARB;
using gl::GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB;
using gl::GL_TEXTURE_COMPRESSION_HINT_ARB;
using gl::GL_TEXTURE_CONSTANT_DATA_SUNX;
using gl::GL_TEXTURE_COORD_ARRAY_ADDRESS_NV;
using gl::GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_TEXTURE_COORD_ARRAY_COUNT_EXT;
using gl::GL_TEXTURE_COORD_ARRAY_EXT;
using gl::GL_TEXTURE_COORD_ARRAY_LENGTH_NV;
using gl::GL_TEXTURE_COORD_ARRAY_LIST_IBM;
using gl::GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM;
using gl::GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL;
using gl::GL_TEXTURE_COORD_ARRAY_POINTER_EXT;
using gl::GL_TEXTURE_COORD_ARRAY_SIZE_EXT;
using gl::GL_TEXTURE_COORD_ARRAY_STRIDE_EXT;
using gl::GL_TEXTURE_COORD_ARRAY_TYPE_EXT;
using gl::GL_TEXTURE_COORD_NV;
using gl::GL_TEXTURE_COVERAGE_SAMPLES_NV;
using gl::GL_TEXTURE_CUBE_MAP_ARB;
using gl::GL_TEXTURE_CUBE_MAP_ARRAY_ARB;
using gl::GL_TEXTURE_CUBE_MAP_EXT;
using gl::GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB;
using gl::GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT;
using gl::GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB;
using gl::GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT;
using gl::GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB;
using gl::GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT;
using gl::GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB;
using gl::GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT;
using gl::GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB;
using gl::GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT;
using gl::GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB;
using gl::GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT;
using gl::GL_TEXTURE_DEFORMATION_SGIX;
using gl::GL_TEXTURE_DEPTH_EXT;
using gl::GL_TEXTURE_DEPTH_SIZE_ARB;
using gl::GL_TEXTURE_DEPTH_TYPE_ARB;
using gl::GL_TEXTURE_DS_SIZE_NV;
using gl::GL_TEXTURE_DT_SIZE_NV;
using gl::GL_TEXTURE_ENV_BIAS_SGIX;
using gl::GL_TEXTURE_FILTER4_SIZE_SGIS;
using gl::GL_TEXTURE_FILTER_CONTROL_EXT;
using gl::GL_TEXTURE_FLOAT_COMPONENTS_NV;
using gl::GL_TEXTURE_FREE_MEMORY_ATI;
using gl::GL_TEXTURE_GEQUAL_R_SGIX;
using gl::GL_TEXTURE_GREEN_SIZE_EXT;
using gl::GL_TEXTURE_GREEN_TYPE_ARB;
using gl::GL_TEXTURE_HI_SIZE_NV;
using gl::GL_TEXTURE_IMMUTABLE_FORMAT_EXT;
using gl::GL_TEXTURE_INDEX_SIZE_EXT;
using gl::GL_TEXTURE_INTENSITY_SIZE_EXT;
using gl::GL_TEXTURE_INTENSITY_TYPE_ARB;
using gl::GL_TEXTURE_LEQUAL_R_SGIX;
using gl::GL_TEXTURE_LIGHT_EXT;
using gl::GL_TEXTURE_LIGHTING_MODE_HP;
using gl::GL_TEXTURE_LO_SIZE_NV;
using gl::GL_TEXTURE_LOD_BIAS_EXT;
using gl::GL_TEXTURE_LOD_BIAS_R_SGIX;
using gl::GL_TEXTURE_LOD_BIAS_S_SGIX;
using gl::GL_TEXTURE_LOD_BIAS_T_SGIX;
using gl::GL_TEXTURE_LUMINANCE_SIZE_EXT;
using gl::GL_TEXTURE_LUMINANCE_TYPE_ARB;
using gl::GL_TEXTURE_MAG_SIZE_NV;
using gl::GL_TEXTURE_MATERIAL_FACE_EXT;
using gl::GL_TEXTURE_MATERIAL_PARAMETER_EXT;
using gl::GL_TEXTURE_MAX_ANISOTROPY;
using gl::GL_TEXTURE_MAX_ANISOTROPY_EXT;
using gl::GL_TEXTURE_MAX_CLAMP_R_SGIX;
using gl::GL_TEXTURE_MAX_CLAMP_S_SGIX;
using gl::GL_TEXTURE_MAX_CLAMP_T_SGIX;
using gl::GL_TEXTURE_MAX_LEVEL_SGIS;
using gl::GL_TEXTURE_MAX_LOD_SGIS;
using gl::GL_TEXTURE_MEMORY_LAYOUT_INTEL;
using gl::GL_TEXTURE_MIN_LOD_SGIS;
using gl::GL_TEXTURE_MULTI_BUFFER_HINT_SGIX;
using gl::GL_TEXTURE_NORMAL_EXT;
using gl::GL_TEXTURE_POST_SPECULAR_HP;
using gl::GL_TEXTURE_PRE_SPECULAR_HP;
using gl::GL_TEXTURE_PRIORITY_EXT;
using gl::GL_TEXTURE_RANGE_LENGTH_APPLE;
using gl::GL_TEXTURE_RANGE_POINTER_APPLE;
using gl::GL_TEXTURE_RECTANGLE_ARB;
using gl::GL_TEXTURE_RECTANGLE_NV;
using gl::GL_TEXTURE_RED_SIZE_EXT;
using gl::GL_TEXTURE_RED_TYPE_ARB;
using gl::GL_TEXTURE_REDUCTION_MODE_ARB;
using gl::GL_TEXTURE_REDUCTION_MODE_EXT;
using gl::GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV;
using gl::GL_TEXTURE_RENDERBUFFER_NV;
using gl::GL_TEXTURE_RESIDENT_EXT;
using gl::GL_TEXTURE_SHADER_NV;
using gl::GL_TEXTURE_SHARED_SIZE_EXT;
using gl::GL_TEXTURE_SPARSE_ARB;
using gl::GL_TEXTURE_SRGB_DECODE_EXT;
using gl::GL_TEXTURE_STENCIL_SIZE_EXT;
using gl::GL_TEXTURE_STORAGE_HINT_APPLE;
using gl::GL_TEXTURE_SWIZZLE_A_EXT;
using gl::GL_TEXTURE_SWIZZLE_B_EXT;
using gl::GL_TEXTURE_SWIZZLE_G_EXT;
using gl::GL_TEXTURE_SWIZZLE_R_EXT;
using gl::GL_TEXTURE_SWIZZLE_RGBA_EXT;
using gl::GL_TEXTURE_TARGET;
using gl::GL_TEXTURE_TILING_EXT;
using gl::GL_TEXTURE_TOO_LARGE_EXT;
using gl::GL_TEXTURE_UNSIGNED_REMAP_MODE_NV;
using gl::GL_TEXTURE_WRAP_Q_SGIS;
using gl::GL_TEXTURE_WRAP_R_EXT;
using gl::GL_TILE_RASTER_ORDER_FIXED_MESA;
using gl::GL_TILE_RASTER_ORDER_INCREASING_X_MESA;
using gl::GL_TILE_RASTER_ORDER_INCREASING_Y_MESA;
using gl::GL_TILING_TYPES_EXT;
using gl::GL_TIME_ELAPSED_EXT;
using gl::GL_TIMELINE_SEMAPHORE_VALUE_NV;
using gl::GL_TRACK_MATRIX_NV;
using gl::GL_TRACK_MATRIX_TRANSFORM_NV;
using gl::GL_TRANSFORM_FEEDBACK_ATTRIBS_NV;
using gl::GL_TRANSFORM_FEEDBACK_BINDING_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_EXT;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_INDEX;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_MODE_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_START_NV;
using gl::GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE;
using gl::GL_TRANSFORM_FEEDBACK_NV;
using gl::GL_TRANSFORM_FEEDBACK_OVERFLOW;
using gl::GL_TRANSFORM_FEEDBACK_OVERFLOW_ARB;
using gl::GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT;
using gl::GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_NV;
using gl::GL_TRANSFORM_FEEDBACK_RECORD_NV;
using gl::GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW;
using gl::GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW_ARB;
using gl::GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT;
using gl::GL_TRANSFORM_FEEDBACK_VARYINGS_EXT;
using gl::GL_TRANSFORM_FEEDBACK_VARYINGS_NV;
using gl::GL_TRANSFORM_HINT_APPLE;
using gl::GL_TRANSLATE_2D_NV;
using gl::GL_TRANSLATE_3D_NV;
using gl::GL_TRANSLATE_X_NV;
using gl::GL_TRANSLATE_Y_NV;
using gl::GL_TRANSPOSE_AFFINE_2D_NV;
using gl::GL_TRANSPOSE_AFFINE_3D_NV;
using gl::GL_TRANSPOSE_COLOR_MATRIX_ARB;
using gl::GL_TRANSPOSE_CURRENT_MATRIX_ARB;
using gl::GL_TRANSPOSE_MODELVIEW_MATRIX_ARB;
using gl::GL_TRANSPOSE_NV;
using gl::GL_TRANSPOSE_PROGRAM_MATRIX_EXT;
using gl::GL_TRANSPOSE_PROJECTION_MATRIX_ARB;
using gl::GL_TRANSPOSE_TEXTURE_MATRIX_ARB;
using gl::GL_TRIANGLE_LIST_SUN;
using gl::GL_TRIANGLE_MESH_SUN;
using gl::GL_TRIANGLE_STRIP_ADJACENCY_ARB;
using gl::GL_TRIANGLE_STRIP_ADJACENCY_EXT;
using gl::GL_TRIANGLES_ADJACENCY_ARB;
using gl::GL_TRIANGLES_ADJACENCY_EXT;
using gl::GL_TRIANGULAR_NV;
using gl::GL_UNCORRELATED_NV;
using gl::GL_UNDEFINED_APPLE;
using gl::GL_UNIFORM_ADDRESS_COMMAND_NV;
using gl::GL_UNIFORM_BLOCK_REFERENCED_BY_MESH_SHADER_NV;
using gl::GL_UNIFORM_BLOCK_REFERENCED_BY_TASK_SHADER_NV;
using gl::GL_UNIFORM_BUFFER_ADDRESS_NV;
using gl::GL_UNIFORM_BUFFER_BINDING_EXT;
using gl::GL_UNIFORM_BUFFER_EXT;
using gl::GL_UNIFORM_BUFFER_LENGTH_NV;
using gl::GL_UNIFORM_BUFFER_UNIFIED_NV;
using gl::GL_UNKNOWN_CONTEXT_RESET;
using gl::GL_UNKNOWN_CONTEXT_RESET_ARB;
using gl::GL_UNKNOWN_CONTEXT_RESET_KHR;
using gl::GL_UNPACK_CLIENT_STORAGE_APPLE;
using gl::GL_UNPACK_CMYK_HINT_EXT;
using gl::GL_UNPACK_CONSTANT_DATA_SUNX;
using gl::GL_UNPACK_IMAGE_DEPTH_SGIS;
using gl::GL_UNPACK_IMAGE_HEIGHT_EXT;
using gl::GL_UNPACK_RESAMPLE_OML;
using gl::GL_UNPACK_RESAMPLE_SGIX;
using gl::GL_UNPACK_ROW_BYTES_APPLE;
using gl::GL_UNPACK_SKIP_IMAGES_EXT;
using gl::GL_UNPACK_SKIP_VOLUMES_SGIS;
using gl::GL_UNPACK_SUBSAMPLE_RATE_SGIX;
using gl::GL_UNSIGNED_BYTE_3_3_2_EXT;
using gl::GL_UNSIGNED_IDENTITY_NV;
using gl::GL_UNSIGNED_INT16_NV;
using gl::GL_UNSIGNED_INT16_VEC2_NV;
using gl::GL_UNSIGNED_INT16_VEC3_NV;
using gl::GL_UNSIGNED_INT16_VEC4_NV;
using gl::GL_UNSIGNED_INT64_AMD;
using gl::GL_UNSIGNED_INT64_ARB;
using gl::GL_UNSIGNED_INT64_NV;
using gl::GL_UNSIGNED_INT64_VEC2_ARB;
using gl::GL_UNSIGNED_INT64_VEC2_NV;
using gl::GL_UNSIGNED_INT64_VEC3_ARB;
using gl::GL_UNSIGNED_INT64_VEC3_NV;
using gl::GL_UNSIGNED_INT64_VEC4_ARB;
using gl::GL_UNSIGNED_INT64_VEC4_NV;
using gl::GL_UNSIGNED_INT8_NV;
using gl::GL_UNSIGNED_INT8_VEC2_NV;
using gl::GL_UNSIGNED_INT8_VEC3_NV;
using gl::GL_UNSIGNED_INT8_VEC4_NV;
using gl::GL_UNSIGNED_INT_10_10_10_2_EXT;
using gl::GL_UNSIGNED_INT_10F_11F_11F_REV_EXT;
using gl::GL_UNSIGNED_INT_24_8_EXT;
using gl::GL_UNSIGNED_INT_24_8_NV;
using gl::GL_UNSIGNED_INT_5_9_9_9_REV_EXT;
using gl::GL_UNSIGNED_INT_8_8_8_8_EXT;
using gl::GL_UNSIGNED_INT_8_8_S8_S8_REV_NV;
using gl::GL_UNSIGNED_INT_IMAGE_1D_ARRAY_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_1D_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_2D_ARRAY_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_2D_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_2D_RECT_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_3D_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_BUFFER_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_CUBE_EXT;
using gl::GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT;
using gl::GL_UNSIGNED_INT_S8_S8_8_8_NV;
using gl::GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_1D_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_2D_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_3D_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_BUFFER_AMD;
using gl::GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_CUBE_EXT;
using gl::GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_ARB;
using gl::GL_UNSIGNED_INT_SAMPLER_RENDERBUFFER_NV;
using gl::GL_UNSIGNED_INT_VEC2_EXT;
using gl::GL_UNSIGNED_INT_VEC3_EXT;
using gl::GL_UNSIGNED_INT_VEC4_EXT;
using gl::GL_UNSIGNED_INVERT_NV;
using gl::GL_UNSIGNED_NORMALIZED_ARB;
using gl::GL_UNSIGNED_SHORT_4_4_4_4_EXT;
using gl::GL_UNSIGNED_SHORT_5_5_5_1_EXT;
using gl::GL_UNSIGNED_SHORT_8_8_APPLE;
using gl::GL_UNSIGNED_SHORT_8_8_MESA;
using gl::GL_UNSIGNED_SHORT_8_8_REV_APPLE;
using gl::GL_UNSIGNED_SHORT_8_8_REV_MESA;
using gl::GL_UPLOAD_GPU_MASK_NVX;
using gl::GL_USE_MISSING_GLYPH_NV;
using gl::GL_UTF16_NV;
using gl::GL_UTF8_NV;
using gl::GL_VARIABLE_A_NV;
using gl::GL_VARIABLE_B_NV;
using gl::GL_VARIABLE_C_NV;
using gl::GL_VARIABLE_D_NV;
using gl::GL_VARIABLE_E_NV;
using gl::GL_VARIABLE_F_NV;
using gl::GL_VARIABLE_G_NV;
using gl::GL_VARIANT_ARRAY_EXT;
using gl::GL_VARIANT_ARRAY_POINTER_EXT;
using gl::GL_VARIANT_ARRAY_STRIDE_EXT;
using gl::GL_VARIANT_ARRAY_TYPE_EXT;
using gl::GL_VARIANT_DATATYPE_EXT;
using gl::GL_VARIANT_EXT;
using gl::GL_VARIANT_VALUE_EXT;
using gl::GL_VBO_FREE_MEMORY_ATI;
using gl::GL_VECTOR_EXT;
using gl::GL_VERTEX_ARRAY_ADDRESS_NV;
using gl::GL_VERTEX_ARRAY_BINDING_APPLE;
using gl::GL_VERTEX_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_VERTEX_ARRAY_COUNT_EXT;
using gl::GL_VERTEX_ARRAY_EXT;
using gl::GL_VERTEX_ARRAY_KHR;
using gl::GL_VERTEX_ARRAY_LENGTH_NV;
using gl::GL_VERTEX_ARRAY_LIST_IBM;
using gl::GL_VERTEX_ARRAY_LIST_STRIDE_IBM;
using gl::GL_VERTEX_ARRAY_OBJECT_AMD;
using gl::GL_VERTEX_ARRAY_OBJECT_EXT;
using gl::GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL;
using gl::GL_VERTEX_ARRAY_POINTER_EXT;
using gl::GL_VERTEX_ARRAY_RANGE_APPLE;
using gl::GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE;
using gl::GL_VERTEX_ARRAY_RANGE_LENGTH_NV;
using gl::GL_VERTEX_ARRAY_RANGE_NV;
using gl::GL_VERTEX_ARRAY_RANGE_POINTER_APPLE;
using gl::GL_VERTEX_ARRAY_RANGE_POINTER_NV;
using gl::GL_VERTEX_ARRAY_RANGE_VALID_NV;
using gl::GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV;
using gl::GL_VERTEX_ARRAY_SIZE_EXT;
using gl::GL_VERTEX_ARRAY_STORAGE_HINT_APPLE;
using gl::GL_VERTEX_ARRAY_STRIDE_EXT;
using gl::GL_VERTEX_ARRAY_TYPE_EXT;
using gl::GL_VERTEX_ATTRIB_ARRAY0_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY10_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY11_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY12_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY13_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY14_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY15_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY1_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY2_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY3_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY4_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY5_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY6_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY7_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY8_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY9_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY_ADDRESS_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_INTEGER_EXT;
using gl::GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY_LENGTH_NV;
using gl::GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB;
using gl::GL_VERTEX_ATTRIB_ARRAY_UNIFIED_NV;
using gl::GL_VERTEX_ATTRIB_MAP1_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP2_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE;
using gl::GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE;
using gl::GL_VERTEX_BLEND_ARB;
using gl::GL_VERTEX_CONSISTENT_HINT_PGI;
using gl::GL_VERTEX_DATA_HINT_PGI;
using gl::GL_VERTEX_ELEMENT_SWIZZLE_AMD;
using gl::GL_VERTEX_ID_NV;
using gl::GL_VERTEX_ID_SWIZZLE_AMD;
using gl::GL_VERTEX_PRECLIP_HINT_SGIX;
using gl::GL_VERTEX_PRECLIP_SGIX;
using gl::GL_VERTEX_PROGRAM_ARB;
using gl::GL_VERTEX_PROGRAM_BINDING_NV;
using gl::GL_VERTEX_PROGRAM_NV;
using gl::GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV;
using gl::GL_VERTEX_PROGRAM_POINT_SIZE_ARB;
using gl::GL_VERTEX_PROGRAM_POINT_SIZE_NV;
using gl::GL_VERTEX_PROGRAM_TWO_SIDE_ARB;
using gl::GL_VERTEX_PROGRAM_TWO_SIDE_NV;
using gl::GL_VERTEX_SHADER_ARB;
using gl::GL_VERTEX_SHADER_BINDING_EXT;
using gl::GL_VERTEX_SHADER_EXT;
using gl::GL_VERTEX_SHADER_INSTRUCTIONS_EXT;
using gl::GL_VERTEX_SHADER_INVARIANTS_EXT;
using gl::GL_VERTEX_SHADER_INVOCATIONS;
using gl::GL_VERTEX_SHADER_INVOCATIONS_ARB;
using gl::GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT;
using gl::GL_VERTEX_SHADER_LOCALS_EXT;
using gl::GL_VERTEX_SHADER_OPTIMIZED_EXT;
using gl::GL_VERTEX_SHADER_VARIANTS_EXT;
using gl::GL_VERTEX_SOURCE_ATI;
using gl::GL_VERTEX_STATE_PROGRAM_NV;
using gl::GL_VERTEX_STREAM0_ATI;
using gl::GL_VERTEX_STREAM1_ATI;
using gl::GL_VERTEX_STREAM2_ATI;
using gl::GL_VERTEX_STREAM3_ATI;
using gl::GL_VERTEX_STREAM4_ATI;
using gl::GL_VERTEX_STREAM5_ATI;
using gl::GL_VERTEX_STREAM6_ATI;
using gl::GL_VERTEX_STREAM7_ATI;
using gl::GL_VERTEX_WEIGHT_ARRAY_EXT;
using gl::GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT;
using gl::GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT;
using gl::GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT;
using gl::GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT;
using gl::GL_VERTEX_WEIGHTING_EXT;
using gl::GL_VERTICAL_LINE_TO_NV;
using gl::GL_VERTICES_SUBMITTED;
using gl::GL_VERTICES_SUBMITTED_ARB;
using gl::GL_VIBRANCE_BIAS_NV;
using gl::GL_VIBRANCE_SCALE_NV;
using gl::GL_VIDEO_BUFFER_BINDING_NV;
using gl::GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV;
using gl::GL_VIDEO_BUFFER_NV;
using gl::GL_VIDEO_BUFFER_PITCH_NV;
using gl::GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV;
using gl::GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV;
using gl::GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV;
using gl::GL_VIDEO_CAPTURE_FRAME_WIDTH_NV;
using gl::GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV;
using gl::GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV;
using gl::GL_VIDEO_COLOR_CONVERSION_MATRIX_NV;
using gl::GL_VIDEO_COLOR_CONVERSION_MAX_NV;
using gl::GL_VIDEO_COLOR_CONVERSION_MIN_NV;
using gl::GL_VIDEO_COLOR_CONVERSION_OFFSET_NV;
using gl::GL_VIEW_CLASS_ASTC_10x10_RGBA;
using gl::GL_VIEW_CLASS_ASTC_10x5_RGBA;
using gl::GL_VIEW_CLASS_ASTC_10x6_RGBA;
using gl::GL_VIEW_CLASS_ASTC_10x8_RGBA;
using gl::GL_VIEW_CLASS_ASTC_12x10_RGBA;
using gl::GL_VIEW_CLASS_ASTC_12x12_RGBA;
using gl::GL_VIEW_CLASS_ASTC_4x4_RGBA;
using gl::GL_VIEW_CLASS_ASTC_5x4_RGBA;
using gl::GL_VIEW_CLASS_ASTC_5x5_RGBA;
using gl::GL_VIEW_CLASS_ASTC_6x5_RGBA;
using gl::GL_VIEW_CLASS_ASTC_6x6_RGBA;
using gl::GL_VIEW_CLASS_ASTC_8x5_RGBA;
using gl::GL_VIEW_CLASS_ASTC_8x6_RGBA;
using gl::GL_VIEW_CLASS_ASTC_8x8_RGBA;
using gl::GL_VIEW_CLASS_EAC_R11;
using gl::GL_VIEW_CLASS_EAC_RG11;
using gl::GL_VIEW_CLASS_ETC2_EAC_RGBA;
using gl::GL_VIEW_CLASS_ETC2_RGB;
using gl::GL_VIEW_CLASS_ETC2_RGBA;
using gl::GL_VIEWPORT_COMMAND_NV;
using gl::GL_VIEWPORT_POSITION_W_SCALE_NV;
using gl::GL_VIEWPORT_POSITION_W_SCALE_X_COEFF_NV;
using gl::GL_VIEWPORT_POSITION_W_SCALE_Y_COEFF_NV;
using gl::GL_VIEWPORT_SWIZZLE_NEGATIVE_W_NV;
using gl::GL_VIEWPORT_SWIZZLE_NEGATIVE_X_NV;
using gl::GL_VIEWPORT_SWIZZLE_NEGATIVE_Y_NV;
using gl::GL_VIEWPORT_SWIZZLE_NEGATIVE_Z_NV;
using gl::GL_VIEWPORT_SWIZZLE_POSITIVE_W_NV;
using gl::GL_VIEWPORT_SWIZZLE_POSITIVE_X_NV;
using gl::GL_VIEWPORT_SWIZZLE_POSITIVE_Y_NV;
using gl::GL_VIEWPORT_SWIZZLE_POSITIVE_Z_NV;
using gl::GL_VIEWPORT_SWIZZLE_W_NV;
using gl::GL_VIEWPORT_SWIZZLE_X_NV;
using gl::GL_VIEWPORT_SWIZZLE_Y_NV;
using gl::GL_VIEWPORT_SWIZZLE_Z_NV;
using gl::GL_VIRTUAL_PAGE_SIZE_INDEX_ARB;
using gl::GL_VIRTUAL_PAGE_SIZE_X_AMD;
using gl::GL_VIRTUAL_PAGE_SIZE_X_ARB;
using gl::GL_VIRTUAL_PAGE_SIZE_Y_AMD;
using gl::GL_VIRTUAL_PAGE_SIZE_Y_ARB;
using gl::GL_VIRTUAL_PAGE_SIZE_Z_AMD;
using gl::GL_VIRTUAL_PAGE_SIZE_Z_ARB;
using gl::GL_VIVIDLIGHT_NV;
using gl::GL_VOLATILE_APPLE;
using gl::GL_W_EXT;
using gl::GL_WARP_SIZE_NV;
using gl::GL_WARPS_PER_SM_NV;
using gl::GL_WEIGHT_ARRAY_ARB;
using gl::GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB;
using gl::GL_WEIGHT_ARRAY_POINTER_ARB;
using gl::GL_WEIGHT_ARRAY_SIZE_ARB;
using gl::GL_WEIGHT_ARRAY_STRIDE_ARB;
using gl::GL_WEIGHT_ARRAY_TYPE_ARB;
using gl::GL_WEIGHT_SUM_UNITY_ARB;
using gl::GL_WEIGHTED_AVERAGE_ARB;
using gl::GL_WEIGHTED_AVERAGE_EXT;
using gl::GL_WIDE_LINE_HINT_PGI;
using gl::GL_WINDOW_RECTANGLE_EXT;
using gl::GL_WINDOW_RECTANGLE_MODE_EXT;
using gl::GL_WRAP_BORDER_SUN;
using gl::GL_WRITE_DISCARD_NV;
using gl::GL_WRITE_ONLY_ARB;
using gl::GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV;
using gl::GL_WRITE_PIXEL_DATA_RANGE_NV;
using gl::GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV;
using gl::GL_X_EXT;
using gl::GL_XOR_NV;
using gl::GL_Y_EXT;
using gl::GL_YCBAYCR8A_4224_NV;
using gl::GL_YCBCR_422_APPLE;
using gl::GL_YCBCR_MESA;
using gl::GL_YCBYCR8_422_NV;
using gl::GL_YCRCB_422_SGIX;
using gl::GL_YCRCB_444_SGIX;
using gl::GL_YCRCB_SGIX;
using gl::GL_YCRCBA_SGIX;
using gl::GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV;
using gl::GL_Z4Y12Z4CB12Z4CR12_444_NV;
using gl::GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV;
using gl::GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV;
using gl::GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV;
using gl::GL_Z_EXT;
using gl::GL_ZERO_EXT;
using gl::GL_ZERO_TO_ONE;


} // namespace gl43ext